<?php

namespace App\Http\Controllers\Auth;

use Illuminate\View\View;
use Illuminate\Http\Request;
use App\Events\AdminLoggedIn;
use App\Events\PartnerLoggedIn;
use App\Events\TeacherLoggedIn;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\RedirectResponse;
use App\Providers\RouteServiceProvider;
use App\Http\Requests\Auth\LoginRequest;
use App\Http\Requests\Auth\LoginAdminRequest;

class AuthenticatedSessionController extends Controller
{
    /**
     * Display the login view.
     */
    public function create(): View
    {
        return view('auth.login');
    }

    /**
     * Handle an incoming authentication request.
     */
    public function store(LoginAdminRequest $request): RedirectResponse
    {
        $guard = '';
        if ($request->type === 'admin') {
            $guard = 'admin';
        } elseif ($request->type === 'teacher') {
            $guard = 'teacher';
        } elseif ($request->type === 'partner') {
            $guard = 'partner';
        }

        if (!$guard) {
            // Handle invalid user type
            return redirect()->back()->with('error', 'يرجى اختيار نوع المستخدم');
        }

        // Explicitly use the specified guard for authentication
        $credentials = $request->only('email', 'password');
        if (Auth::guard($guard)->attempt($credentials)) {
            $request->session()->regenerate();
            if ($guard === 'admin') {
                event(new AdminLoggedIn(Auth::guard($guard)->user(), false));
            } elseif ($guard === 'teacher') {
                event(new TeacherLoggedIn(Auth::guard($guard)->user(), false));
            } elseif ($guard === 'partner') {
                event(new PartnerLoggedIn(Auth::guard($guard)->user(), false));
            }
            return redirect()->intended(RouteServiceProvider::HOME);
        }

        return redirect()->back()->withInput($request->only('email'))->with('error', 'بيانات خاطئة، يرجى التحقق والمحاولة مرة ثانية!!');
    }

    /**
     * Destroy an authenticated session.
     */
    public function destroy(Request $request): RedirectResponse
    {

        Auth::guard('web')->logout();

        $request->session()->invalidate();

        $request->session()->regenerateToken();

        return redirect()->route('login');
    }
}
