<?php

namespace App\Http\Controllers;

use App\Models\Teacher;
use App\Models\Category;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\CategoryRequest;

class CategoryController extends Controller
{
    public function index()
    {
        $pageInfo['title'] = 'البطاقات';
        $from = "2024-01-01T00:00:00";
        $to = now();
        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['categories-list']))|| auth('partner')->check() || auth('teacher')->check()){
            $categories = Category::all();
            return view('admin.categories.index', compact('from','to','categories', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function categoryinfo($category)
    {
        try {
            $category = Category::where('id', $category)->first();
            if($category){
                return response()->json(['success' =>  $category]);
            } else {
                return response()->json(['error' =>  'الفئة غير موجودة']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }
    public function categoryTeachers($category)
    {
        try {
            $category = Category::where('id', $category)->first();
            if($category){
                $teachers = Teacher::whereHas('cards', function ($query) use ($category) {
                    $query->where('category_id', $category->id);
                })->get();
                return response()->json(['success' =>  $teachers]);
            } else {
                return response()->json(['error' =>  'الفئة غير موجودة']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            //dd($e->getMessage());
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }
        /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $pageInfo['title']= 'إضافة فئة';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['categories-add'])){
            return view('admin.categories.create', compact('pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }


    public function store(CategoryRequest $request)
    {
        $pageInfo['title']= 'إضافة فئة';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['categories-add'])){
            try {
                DB::beginTransaction ();
                $data = [
                    'type' => $request->type,
                    'name' => $request->name,
                    'price' => str_replace(',', '', $request->price),
                    'price_company' => str_replace(',', '', $request->price_company),
                    'price_point_sale' => str_replace(',', '', $request->price_point_sale),
                ];
                if($request->type == 'amount'){
                    $data['teacher_amount']=str_replace(',', '', $request->teacher_percentage);
                } else {
                    $data['teacher_percentage']=str_replace(',', '', $request->teacher_percentage) ;
                }
                if( $request->has('status') ){
                    $data['status']="active";
                }else{
                    $data['status']="inactive";
                }
                $category = Category::create($data);


                DB::commit();
                return to_route('categories.index')->with('message','تم اضافة الفئة بنجاح');
            }catch(\Exception $e){
                Log::info($e->getMessage());
                //dd($e->getMessage());
                DB::rollBack();
                return to_route('categories.index')->with('error','حدث شيء ما خاطئ');
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

        /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        $pageInfo['title']= 'تعديل الفئة';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['categories-edit'])){
            $category = Category::find($id);


            return view('admin.categories.edit', compact('pageInfo', 'category'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    public function update(CategoryRequest $request, $id)
    {
        $pageInfo['title']= 'تعديل الفئة';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['categories-edit'])){
            try {
                DB::beginTransaction ();
                $category=Category::find($id);
                $data = [
                    'type' => $request->type,
                    'name' => $request->name,
                    'price' => str_replace(',', '', $request->price),
                    'price_company' => str_replace(',', '', $request->price_company),
                    'price_point_sale' => str_replace(',', '', $request->price_point_sale),
                ];
                if($request->type == 'amount'){
                    $data['teacher_amount']=str_replace(',', '', $request->teacher_percentage);
                } else {
                    $data['teacher_percentage']=str_replace(',', '', $request->teacher_percentage) ;
                }

                if( $request->has('status') ){
                    $data['status']="active";
                }else{
                    $data['status']="inactive";
                }
                $category->update($data);

                DB::commit();
                return to_route('categories.index')->with('message','تم تعديل معلومات الفئة');
            }catch(\Exception $e){
                Log::info($e->getMessage());
                //dd($e->getMessage());
                DB::rollBack();
                return to_route('admin.categories.index')->with('error','حدث شيء ما خاطئ');
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy( $id)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['categories-delete'])){
            try {
                $category=Category::find($id);
                if ($category->subscriptions->count() > 0){
                    return response()->json(['error' =>  'عذراً لا يمكن الحذف ، يوجد اشتراكات مرتبطة بهذه الفئة']);
                }elseif  ($category){
                    $category->cards()->delete();
                    $category->delete();
                    return response()->json([
                        'error'=>false,
                    ]);
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'الفئة غير موجودة',
                    ]);
                }
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }


    }
}

