<?php

namespace App\Http\Controllers;

use App\Models\Company;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\CompanyRequest;

class CompanyController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = 'شركات التوصيل';
        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['companies-list'])) || auth('partner')->check()){
         $companies = Company::all();

         return view('admin.companies.index', compact('companies', 'pageInfo'));
         }else{
             return view('admin.pages.not_allowed', compact('pageInfo'));
         }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $pageInfo['title']= 'إضافة شركة';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['companies-add'])){
            return view('admin.companies.create', compact('pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(CompanyRequest $request)
    {
        $pageInfo['title']= 'إضافة شركة توصيل';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['companies-add'])){
            try {
                DB::beginTransaction ();
                $company = Company::create([
                    'name' => $request->name,
                    'email' => $request->email,
                    'phone'=>$request->phone,
                    'address'=>$request->address,
                    'notes'=>$request->notes,
                    'delivery_fees' => str_replace(',', '', $request->delivery_fees),
                    'status'=>"active"
                ]);
               /*  if( $request->has('email') ){
                    $company->status="active";
                } */
                $company->save();
                DB::commit();
                return to_route('companies.index')->with('message',trans('تم اضافة شركة توصيل بنجاح'));
            }catch(\Exception $e){
                Log::info($e->getMessage());
                //dd($e->getMessage());
                DB::rollBack();
                return to_route('companies.index')->with('error',trans('حدث شيء ما خاطئ'));
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Display the specified resource.
     */
    public function show(Company $company)
    {
        $pageInfo['title']= 'بروفايل الشركة';
        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['companies-show']))|| auth('partner')->check()){
            return view('admin.companies.show', compact('pageInfo', 'company'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Company $company)
    {
        $pageInfo['title']= 'تعديل شركة التوصيل';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['companies-edit'])){
            return view('admin.companies.edit', compact('pageInfo', 'company'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(CompanyRequest $request, Company $company)
    {
        $pageInfo['title']= 'تعديل شركة التوصيل';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['companies-edit'])){
            try {
                DB::beginTransaction ();
                $company->update([
                    'name' => $request->name,
                    'email' => $request->email,
                    'phone'=>$request->phone,
                    'address'=>$request->address,
                    'notes'=>$request->notes,
                    'delivery_fees' => str_replace(',', '', $request->delivery_fees),
                    'status'=>"active"
                ]);

                $company->save();
                DB::commit();
                return to_route('companies.index')->with('message',trans('تم تعديل معلومات الشركة'));
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return to_route('companies.index')->with('error',trans('حدث شيء ما خاطئ'));
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Company $company)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['companies-delete'])){
            try {
                if  ($company){
                    $company->delete();
                    return response()->json([
                        'error'=>false,
                    ]);
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }

    }
}
