<?php

namespace App\Http\Controllers;

use App\Models\Course;
use App\Models\Teacher;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use App\Http\Requests\CourseRequest;
use Illuminate\Support\Facades\Auth;

class CourseController extends Controller
{
        /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = trans('all.courses');

        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['courses-list'])) || auth('partner')->check()){
            $courses = Course::all();
            $teachers = Teacher::all();
            return view('admin.courses.index', compact('courses', 'pageInfo','teachers'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function teacherCourses($teacher)
    {
        try {
            $teacher = Teacher::where('id', $teacher)->with('courses')->first();
            if($teacher){
                return response()->json(['success' =>  $teacher]);
            } else {
                return response()->json(['error' =>  'المعلم غير موجود']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }


    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(CourseRequest $request)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['courses-add'])){
            try {
                DB::beginTransaction ();
                    $course = Course::create([
                        'title' => $request->title,
                        'price' => str_replace(',', '', $request->price),
                        'teacher_id' => $request->teacher_id,
                    ]);
                    $course->save();
                DB::commit();
                return response()->json(['success' =>  $course]);
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للإضافة']);
        }

    }

    /**
     * Display the specified resource.
     */
    public function show(Course $course)
    {
        try {
            if($course){
                return response()->json(['success' =>  $course]);
            } else {
                return response()->json(['error' =>  'الدورة غير موجودة']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Course $course)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(CourseRequest $request, Course $course)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['courses-edit'])){
            try {
                if($course){
                    DB::beginTransaction ();
                        $course->update([
                            'title' => $request->title,
                            'price' => str_replace(',', '', $request->price_edit),
                            'teacher_id' => $request->teacher_id,
                        ]);
                        $course->save();
                    DB::commit();
                    return response()->json(['success' =>  $course]);
                } else {
                    return response()->json(['error' =>  'الدورة غير موجود']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للتعديل']);
        }

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Course $course)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['courses-delete'])){
            try {
                if  ($course){
                    $course->delete();
                    return response()->json([
                        'error'=>false,
                    ]);
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }


    }
}
