<?php

namespace App\Http\Controllers;

use App\Models\Card;
use App\Models\CourseSupply;
use Illuminate\Http\Request;
use App\Models\suppliesupply;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\CourseSupplyRequest;

class CourseSupplyController extends Controller
{
      /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = 'المستلزمات';

        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['supplies-list'])) || auth('partner')->check()){
            $supplies = CourseSupply::with('card')->get();
            $cards = Card::with('courses')->get();
            return view('admin.supplies.index', compact('cards','supplies', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }


    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(CourseSupplyRequest $request)
    {

        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['supplies-add'])){
            try {
                DB::beginTransaction ();
                    $supply = CourseSupply::create([
                        'name' => $request->name,
                        'card_id' => $request->card_id,
                        'price' => str_replace(',', '', $request->price),
                        'quantity' => str_replace(',', '', $request->quantity),
                    ]);
                    $supply->save();
                DB::commit();
                return response()->json(['success' =>  $supply]);
            }catch(\Exception $e){
                Log::info($e->getMessage());
                //dd($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للإضافة']);
        }

    }

    /**
     * Display the specified resource.
     */
    public function show(CourseSupply $supply)
    {
        try {
            if($supply){
                return response()->json(['success' =>  $supply]);
            } else {
                return response()->json(['error' =>  'المستلزمات المطلوبة غير موجودة']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(CourseSupply $supply)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(CourseSupplyRequest $request, CourseSupply $supply)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['supplies-edit'])){
            try {
                if($supply){
                    DB::beginTransaction ();
                        $supply->update([
                            'name' => $request->name,
                            'price' => str_replace(',', '', $request->price_edit),
                            'card_id' => $request->card_id,
                            'quantity' => str_replace(',', '', $request->quantity),
                        ]);
                        $supply->save();
                    DB::commit();
                    return response()->json(['success' =>  $supply]);
                } else {
                    return response()->json(['error' =>  'المستلزمات المطلوبة غير موجودة']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للتعديل']);
        }

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(CourseSupply $supply)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['supplies-delete'])){
            try {
                if  ($supply){
                    $supply->delete();
                    return response()->json([
                        'error'=>false,
                    ]);
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }


    }
}
