<?php

namespace App\Http\Controllers;

use App\Models\Section;
use App\Models\Employee;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\EmployeeRequest;

class EmployeeController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = 'الموظفون';
        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['employees-list'])) || auth('partner')->check()){
         $employees = Employee::all();
         $salaries_total = $employees->where('status','active')->sum('salary');;
         return view('admin.employees.index', compact('employees', 'pageInfo','salaries_total'));
         }else{
             return view('admin.pages.not_allowed', compact('pageInfo'));
         }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $pageInfo['title']= 'إضافة موظف';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['employees-add'])){
            $sections = Section::all();
            return view('admin.employees.create', compact('pageInfo','sections'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(EmployeeRequest $request)
    {
      //  dd('y');
        $pageInfo['title']= 'إضافة موظف';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['employees-add'])){
            try {
                DB::beginTransaction ();
                $employee = Employee::create([
                    'name' => $request->name,
                    'email' => $request->email,
                    'phone'=>$request->phone,
                    'salary'=>$request->salary,
                    'notes'=>$request->notes,
                    'specialization'=>$request->specialization,
                ]);
                if( $request->has('status') ){
                    $employee->status="active";
                }else{
                    $employee->status='inactive';
                }
                $employee->save();
                DB::commit();
                return to_route('employees.index')->with('message',trans('تم اضافة الموظف بنجاح'));
            }catch(\Exception $e){
                Log::info($e->getMessage());
                dd($e->getMessage());
                DB::rollBack();
                return to_route('employees.index')->with('error',trans('حدث شيء ما خاطئ'));
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Display the specified resource.
     */
    public function show(Employee $employee)
    {
        $pageInfo['title']= 'بروفايل الموظف';
        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['employees-show']))|| auth('partner')->check()){
            return view('admin.employees.show', compact('pageInfo', 'employee'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Employee $employee)
    {
        $pageInfo['title']= 'تعديل الموظف';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['employees-edit'])){
            $sections = Section::all();
            return view('admin.employees.edit', compact('pageInfo', 'employee','sections'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(EmployeeRequest $request, Employee $employee)
    {
        $pageInfo['title']= 'تعديل الموظف';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['employees-edit'])){
            try {
                DB::beginTransaction ();
                $employee->update([
                    'name' => $request->name,
                    'email' => $request->email,
                    'phone'=>$request->phone,
                    'salary'=>$request->salary,
                    'notes'=>$request->notes,
                    'specialization'=>$request->specialization,
                ]);
                if( $request->has('status') ){
                    $employee->status="active";
                }else{
                    $employee->status='inactive';
                }
                $employee->save();
                DB::commit();
                return to_route('employees.index')->with('message',trans('تم تعديل معلومات الموظف'));
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return to_route('employees.index')->with('error',trans('حدث شيء ما خاطئ'));
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Employee $employee)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['employees-delete'])){
            try {
                if ($employee->payments->count() > 0 ){
                    return response()->json(['error' =>  'عذراً لا يمكن الحذف ، يوجد رواتب مرتبطة بهذا الحساب']);
                }elseif  ($employee){
                    $employee->delete();
                    return response()->json([
                        'error'=>false,
                    ]);
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }

    }
}
