<?php

namespace App\Http\Controllers;

use App\Models\Expense;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\ExpenseRequest;

class ExpenseController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = 'النفقات';
        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['expenses-list']))|| auth('partner')->check()){
         $expenses = Expense::all();

         return view('admin.expenses.index', compact('expenses', 'pageInfo'));
         }else{
             return view('admin.pages.not_allowed', compact('pageInfo'));
         }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(ExpenseRequest $request)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['expenses-add'])){
            try {
                DB::beginTransaction ();
                    $expense = Expense::create([
                        'title' => $request->title,
                    ]);
                    $expense->save();
                DB::commit();
                return response()->json(['success' =>  $expense]);
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للإضافة']);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show($id)
    {
        try {
            $expense = Expense::where('id', $id)->first();
            if($expense){
                return response()->json(['success' =>  $expense]);
            } else {
                return response()->json(['error' =>  'النفقة غير موجود']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Expense $expense)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['expenses-edit'])){
            try {
                $expense = Expense::where('id', $id)->first();
                if($expense){
                    DB::beginTransaction ();
                        $expense->update([
                            'title' => $request->title
                        ]);
                        $expense->save();
                    DB::commit();
                    return response()->json(['success' =>  $expense]);
                } else {
                    return response()->json(['error' =>  'النفقة غير موجود']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للتعديل']);
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy($id)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['expenses-delete'])){
            try {
                $expense=Expense::find($id);
                if ($expense->payments->count() > 0 ){
                    return response()->json(['error' =>  'عذراً لا يمكن الحذف ، يوجد مدفوعات مرتبطة بهذه النفقة']);
                }elseif  ($expense){
                    $expense->delete();
                    return response()->json([
                        'error'=>false,
                    ]);
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }

        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }
    }
}
