<?php

namespace App\Http\Controllers;

use App\Models\Card;
use App\Models\Order;
use App\Models\Region;
use App\Models\Company;
use App\Models\Teacher;
use App\Models\Category;
use App\Helpers\OrderHelper;
use App\Models\CourseSupply;
use Illuminate\Http\Request;
use App\Models\CourseSupplyOrder;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\OrderRequest;
use App\Models\CardOrder;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;

class OrderController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = 'الطلبات';
        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['orders-list'])) || auth('partner')->check()){
        $orders = Order::all();

        return view('admin.orders.index', compact('orders', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $pageInfo['title']= 'إضافة طلب';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['orders-add'])){
            $categories = Category::where('type', '<>' , 'amount')->get();
            $companies = Company::all();
            $supplies = CourseSupply::all();
            $regions = Region::all();
            //$teachers = Teacher::all();
            return view('admin.orders.create', compact('pageInfo','categories','companies','supplies','regions'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(OrderRequest $request)
    {
        //  dd($request->all());
        $pageInfo['title']= 'إضافة طلب ';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['orders-add'])){
            try {
                DB::beginTransaction ();
               // dd($request->all());
               /// $totalFloat = floatval($request->total); // Convert to float
               // $total = (int) $totalFloat; // Convert to integer (truncates decimal)
                   $total = str_replace(',', '', $request->total);
               // dd($total);
                $company = Company::where('id', $request->company_id)->first();
                $newOrder = Order::create([
                    'code' => OrderHelper::generateOrderCode(),
                    'user_name' => $request->user_name,
                    'phone'=>$request->phone,
                    'company_id' => $request->company_id,
                    'delivery_fees' => $company->delivery_fees,
                    'region_id' => $request->region_id,
                    'address'=>$request->address,
                    'total' => $total,
                    'notes'=>$request->notes,
                    'status'=>$request->status
                ]);
                $newOrder->save();
                if ($request->has('orders')) {
                    foreach ($request->orders as $order) {
                        //dd();
                        if(isset($order['number_of_cards']) && $order['number_of_cards'] > 0){

                            $category = Category::find($order['category_id']);
                            $number_of_cards = str_replace(',', '', $order['number_of_cards']);

                            $courseSupplyOrder =  CardOrder::create([
                                'category_id' => $order['category_id'],
                                'teacher_id' => $order['teacher_id'],
                                'card_id' => $order['card_id'],
                                'order_id' => $newOrder->id,
                                'price' => $category->price_company,
                                'quantity' => $number_of_cards,
                                'total'=> $number_of_cards * $category->price_company
                            ]);

                        }
                        if (array_key_exists('supplies', $order)) {
                            foreach ($order['supplies'] as $sup) {
                                $supply = CourseSupply::find($sup['supply_id']);
                                if ($supply) {
                                    $supply_num = str_replace(',', '', $sup['supply_num']);
                                    //dd($sup);
                                    $courseSupplyOrder =  CourseSupplyOrder::create([
                                        'category_id' => $order['category_id'],
                                        'teacher_id' => $order['teacher_id'],
                                        'card_id' => $order['card_id'],
                                        'order_id' => $newOrder->id,
                                        'course_supply_id'=> $supply->id,
                                        'price' => $supply->price,
                                        'quantity' => $supply_num,
                                        'total'=> $supply_num * $supply->price
                                    ]);
                                    //dd($courseSupplyOrder);
                                }

                                $supply->update([
                                    'quantity' => $supply->quantity - $supply_num,
                                ]);
                            }
                        }

                    }
                }
                DB::commit();
                return to_route('orders.print' , $newOrder->id)->with('message',trans('تم اضافة طلب  بنجاح'));
            }catch(\Exception $e){
                Log::info($e->getMessage());
                dd($e->getMessage());
                DB::rollBack();
                return to_route('orders.index')->with('error',trans('حدث شيء ما خاطئ'));
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Display the specified resource.
     */
    public function show(Order $order)
    {
        $pageInfo['title']= 'بروفايل الطلب';
        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['orders-show']))|| auth('partner')->check()){
            return view('admin.orders.show', compact('pageInfo', 'order'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function orderPrint(Order $order)
    {
        $pageInfo['title']= 'الفاتورة';
        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['orders-show']))|| auth('partner')->check()){
            return view('admin.orders.print', compact('pageInfo', 'order'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Order $order)
    {
        $pageInfo['title']= 'تعديل الطلب';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['orders-edit'])){
            $categories = Category::where('type', '<>' , 'amount')->get();
            $companies = Company::all();
            $supplies = CourseSupply::all();
            $regions = Region::all();


            $teachers = Teacher::whereHas('cards', function ($query) use ($order) {
                $query->where('category_id', $order->category_id);
            })->get();
            $cards = Card::where('teacher_id',$order->teacher_id)->where('category_id',$order->category_id)->with(['courses','category'])->get();
            return view('admin.orders.edit', compact('pageInfo', 'order','categories','companies','supplies','teachers','regions','cards'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(OrderRequest $request, Order $order)
    {
        $pageInfo['title']= 'تعديل الطلب ';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['orders-edit'])){
            try {
                DB::beginTransaction ();
               /*  $totalFloat = floatval($request->total); // Convert to float
                $total = (int) $totalFloat; // Convert to integer (truncates decimal)
                dd( $total); */
                $total = str_replace(',', '', $request->total);
                //dd( $total);
                $company = Company::where('id', $request->company_id)->first();
                $order->update([
                    'code' => $order->code,
                    'user_name' => $request->user_name,
                    'phone'=>$request->phone,
                    'company_id' => $request->company_id,
                    'delivery_fees' => $company->delivery_fees,
                    'region_id' => $request->region_id,
                    'address'=>$request->address,
                    'total' => $total,
                    'notes'=>$request->notes,
                    'status'=>$request->status
                ]);

                //$newOrder->save();
                $supplies_old =CourseSupplyOrder::where('order_id', $order->id)->get();
                foreach($supplies_old as $supply){
                    $supply->delete();
                }

                $cards_old =CardOrder::where('order_id', $order->id)->get();

                foreach($cards_old as $card){
                    $card->delete();
                }

                if ($request->has('orders')) {
                    foreach ($request->orders as $order1) {

                        if(isset($order1['number_of_cards']) && $order1['number_of_cards'] > 0){

                            $category = Category::find($order1['category_id']);
                            $number_of_cards = str_replace(',', '', $order1['number_of_cards']);

                            $courseSupplyOrder =  CardOrder::create([
                                'category_id' => $order1['category_id'],
                                'teacher_id' => $order1['teacher_id'],
                                'card_id' => $order1['card_id'],
                                'order_id' => $order->id,
                                'price' => $category->price_company,
                                'quantity' => $number_of_cards,
                                'total'=> $number_of_cards * $category->price_company
                            ]);

                        }

                        if (array_key_exists('supplies', $order1)) {
                            foreach ($order1['supplies'] as $sup) {

                                $supply = CourseSupply::find($sup['supply_id']);

                                if ($supply) {
                                    $supply_num = str_replace(',', '', $sup['supply_num']);

                                    $courseSupplyOrder =  CourseSupplyOrder::create([
                                        'category_id' => $sup['category_id'],
                                        'teacher_id' => $sup['teacher_id'],
                                        'card_id' => $sup['card_id'],
                                        'order_id' => $order->id,
                                        'course_supply_id'=> $supply->id,
                                        'price' => $supply->price,
                                        'quantity' => $supply_num,
                                        'total'=> $supply_num * $supply->price
                                    ]);
                                    //dd($courseSupplyOrder);
                                    $supply->update([
                                        'quantity' => $supply->quantity - $supply_num,
                                    ]);
                                }
                                // dd($supply);

                            }
                        }

                    }
                }
               /*  $category = Category::find($request->category_id);
                $number_of_cards = str_replace(',', '', $request->number_of_cards);
                $total = str_replace('.', '', $request->total);
                //dd($request->all());
                $order->update([
                    'code' => $order->code,
                    'category_id' => $request->category_id,
                    'teacher_id' => $request->teacher_id,
                    'card_id' => $request->card_id,
                    'price' => $category->price,
                    'number_of_cards' => $number_of_cards,
                    'company_id' => $request->company_id,
                    'user_name' => $request->user_name,
                    'phone'=>$request->phone,
                    'address'=>$request->address,
                    'total' => $total,
                    'notes'=>$request->notes,
                    'status'=>$request->status
                ]);
                $order->save();

                $supplies =CourseSupplyOrder::where('order_id', $order->id)->get();
                foreach($supplies as $supply){
                    $supply->delete();
                }

                if ($request->has('supplies')) {
                    foreach ($request->supplies as $supply) {

                        $supply = CourseSupply::find($supply);
                        if ($supply) {
                            $courseSupplyOrder =  CourseSupplyOrder::create([
                                'order_id' => $order->id,
                                'course_supply_id'=> $supply->id,
                                'price'=> $supply->price
                            ]);
                            //dd($courseSupplyOrder);
                        }
                    }
                }
 */
                DB::commit();
                return to_route('orders.print',$order->id)->with('message',trans('تم تعديل معلومات الطلب'));
            }catch(\Exception $e){
                Log::info($e->getMessage());
                dd($e->getMessage());
                DB::rollBack();
                return to_route('orders.index')->with('error',trans('حدث شيء ما خاطئ'));
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Order $order)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['orders-delete'])){
            //dd($order->supplies);
            try {
                if  ($order){
                    $supplies =CourseSupplyOrder::where('order_id', $order->id)->get();
                    foreach($supplies as $supply){
                        $supply->delete();
                    }

                    $cards =CardOrder::where('order_id', $order->id)->get();

                    foreach($cards as $card){
                        $card->delete();
                    }

                    $order->delete();
                    return response()->json([
                        'error'=>false,
                    ]);
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'الطلب غير موجود',
                    ]);
                }
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }

    }
}
