<?php

namespace App\Http\Controllers;

use Carbon\Carbon;
use App\Models\Card;
use App\Models\Partner;
use App\Models\Payment;
use App\Models\Teacher;
use App\Models\Subscription;
use Illuminate\Http\Request;
use App\Models\PartnerPayment;
use App\Models\TeacherPayment;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Database\Eloquent\Builder;

class PageController extends Controller
{
    public function index()
    {
        $pageInfo['title'] = 'الرئيسية';

        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['profits-list']))|| auth('partner')->check()){
            //$salaries = Payment::where('expense_id', 1)->with('employee')->get();
            $salaries = Payment::where('expense_id', 1)->with('employee')->get();
            $salaries_total = $salaries->sum('amount');
            $payments = Payment::all();
            $payments_total= $payments->sum('amount');
            $subscriptions = Subscription::where('type','platform')->where('paid',1)->get();
            //$subscriptions_total = $subscriptions->sum('partners_amount');
            $subscriptions_total = $subscriptions->sum('total');
            $subscriptions_count = $subscriptions->count();

            $sales = Subscription::where('type','pos')->where('paid',1)->get();
            $sales_total = $sales->sum('partners_amount');

            $partnerPayments = PartnerPayment::all();
            $partnerPayments_total= $partnerPayments->sum('amount');

            $teacherPayments = TeacherPayment::all();
            $teacherPayments_total= $teacherPayments->sum('amount');


            $cash = $subscriptions_total - ($payments_total + $partnerPayments_total + $teacherPayments_total);
            //dd($cash);
            //$cards = Card::withSum('subscriptions', 'number_of_cards')->get()->orderBySum('subscriptions', 'number_of_cards');
            $cards = Card::withSum([
                'subscriptions' => function (Builder $query) {
                    $query->where('paid', true);
                }
            ], 'number_of_cards')
                ->get()
                ->orderBySum('subscriptions', 'number_of_cards')->take(7);;

                $cardsData = [];
                foreach($cards as $card) {
                    $course_titles = []; // Array to store course titles

                    foreach ($card->courses as $course ){
                        $course_titles[] = $course->title;
                    }

                    // Join course titles with "-"
                    $course_title_string = implode('-', $course_titles);

                    $cardsData['label'][] = $course_title_string .' - ' .$card->teacher->name;
                    $cardsData['data'][] = (int) ($card->subscriptions_sum_number_of_cards) ? $card->subscriptions_sum_number_of_cards : 0;
                }
            $cardsData['chart_data'] = json_encode($cardsData);
            //dd($cardsData);

          /*   $partners = [];
            $all_partners = Partner::all();
            $Subscriptions_amount = Subscription::sum('total');
            $payments = Payment::sum('amount');
            $partners_amount = $Subscriptions_amount - $payments;

            foreach($all_partners as $partner) {
                $partners['label'][] = $partner->name;
                $partners['data'][] = (int) $partners_amount * $partner->percentage ;
            }

            $partners['chart_data'] = json_encode($partners); */
           // dd($partners);
            //dd($Profits);
           /*  $profits = [];
            $months = [];
            $now = Carbon::now();

            for ($i = 11; $i >= 0; $i--) {
                $month = $now->copy()->subMonths($i);
                $months[] = $month->translatedFormat('F Y');

                $profits['label'][] = $month->translatedFormat('F Y');

                // Get the start and end date of the month
                $startOfMonth = $month->copy()->startOfMonth();
                $endOfMonth = $month->copy()->endOfMonth();

                $month_subscriptions = Subscription::where('type', 'platform')
                                                ->where('paid', 1)
                                                ->whereBetween('created_at', [$startOfMonth, $endOfMonth])
                                                ->sum('total');

                $profits['data']['subscriptions'][] = (int) $month_subscriptions; // Use count() for the number of subscriptions

                $month_payments = Payment::whereBetween('created_at', [$startOfMonth, $endOfMonth])
                                                ->sum('amount');

                $profits['data']['payments'][] = (int) $month_payments; // Use count() for the number of payments
            }
            //dd($profits);


            $profits['chart_data'] = json_encode($profits); */
            //dd($profits['chart_data']);
            //////

            //$teachers = Teacher::all();
            $teachers = Teacher::orderBy('total_amount', 'desc')->get();
            $teachers = $teachers->sortByDesc(function ($teacher) {
                return (float) $teacher->total_amount;
            })->take(7);

            $topPartners = Partner::with(['subscriptions','payments'])->get();

           // dd($teachers);
/*             return view('admin.index', compact('subscriptions_count','topPartners','teachers','partnerPayments_total','teacherPayments_total','cash','partners','profits','cardsData','cards','payments','subscriptions','salaries','salaries_total','payments_total','subscriptions_total','sales_total', 'pageInfo'));
 */            return view('admin.index', compact('subscriptions_count','topPartners','teachers','partnerPayments_total','teacherPayments_total','cash','cards','payments','subscriptions','salaries','salaries_total','payments_total','subscriptions_total','sales_total', 'pageInfo'));
        }else if(auth('teacher')->check()){
            $cards = Card::where('teacher_id', auth('teacher')->user()->id )->withSum([
                'subscriptions' => function (Builder $query) {
                    $query->where('paid', true);
                }
            ], 'number_of_cards')
                ->get()
                ->orderBySum('subscriptions', 'number_of_cards')->take(7);;

                $cardsData = [];
                foreach($cards as $card) {
                    $course_titles = []; // Array to store course titles

                    foreach ($card->courses as $course ){
                        $course_titles[] = $course->title;
                    }

                    // Join course titles with "-"
                    $course_title_string = implode('-', $course_titles);

                    $cardsData['label'][] = $course_title_string .' - ' .$card->teacher->name;
                    $cardsData['data'][] = (int) ($card->subscriptions_sum_number_of_cards) ? $card->subscriptions_sum_number_of_cards : 0;
                }
                $cardsData['chart_data'] = json_encode($cardsData);
//////////////////////////

            $profits = [];
            $months = [];
            $now = Carbon::now();

            for ($i = 11; $i >= 0; $i--) {
                $month = $now->copy()->subMonths($i);
                $months[] = $month->translatedFormat('F Y');

                $profits['label'][] = $month->translatedFormat('F Y');

                // Get the start and end date of the month
                $startOfMonth = $month->copy()->startOfMonth();
                $endOfMonth = $month->copy()->endOfMonth();

                $month_subscriptions = Subscription::where('type', 'platform')
                                                ->where('paid', 1)
                                                ->where('teacher_id', auth('teacher')->user()->id )
                                                ->whereBetween('created_at', [$startOfMonth, $endOfMonth])
                                                ->sum('teacher_amount');

                $profits['data'][] = (int) $month_subscriptions; // Use count() for the number of subscriptions

            }
           // dd($profits);

            $profits['chart_data'] = json_encode($profits);
            return view('admin.index', compact('pageInfo','cardsData','profits'));

        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
}
