<?php

namespace App\Http\Controllers;

use Carbon\Carbon;
use App\Models\Partner;
use App\Models\Payment;
use App\Models\Subscription;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use App\Http\Requests\PartnerRequest;
use App\Models\PartnerPayment;

class PartnerController extends Controller
{
    public function index()
    {
        $pageInfo['title'] = 'الشركاء';
       if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['partners-list'])) || auth('partner')->check()){
        $partners = Partner::all();
        $endDate = Carbon::now()->subMonth()->endOfMonth();
        //$allPayments = Payment::where('created_at', '<=' ,$endDate)->get();
        $allPayments = Payment::get();
        $all_payments_total= $allPayments->sum('amount');
        $all_day_payments_total = Payment::get();
        $all_day_payments_total= $all_day_payments_total->sum('amount');

       // $allSubscriptions = Subscription::where('type','platform')->where('paid',1)->where('created_at', '<=' ,$endDate)->get();
        $allSubscriptions = Subscription::where('type','platform')->where('paid',1)->get();
        $all_subscriptions_total = $allSubscriptions->sum('partners_amount');

        $all_day_subscriptions_total = Subscription::where('type','platform')->where('paid',1)->get();
        $all_day_subscriptions_total = $all_day_subscriptions_total->sum('partners_amount');

        $allAmont = $all_subscriptions_total - $all_payments_total;
        $allDayAmont = $all_day_subscriptions_total - $all_day_payments_total;


        foreach($partners as $partner){
            $partner->amount = $allAmont * ($partner->percentage / 100);
            $partner->dayAmount = $allDayAmont * ($partner->percentage / 100);
        }
        return view('admin.partners.index', compact('partners', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function partnersPercentage()
    {
        $pageInfo['title'] = 'نسبة الشركاء';
       if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['partners-percentage'])) || auth('partner')->check()){
        $partners = Partner::all();

        return view('admin.partners.percentage.index', compact('partners', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function getInfo($partner)
    {
        try {
            $partner = Partner::where('id', $partner)->first();
            if($partner){
                $endDate = Carbon::now()->subMonth()->endOfMonth();
                //dd($endDate);
               // $allPayments = Payment::where('created_at', '<=' ,$endDate)->get();
                $allPayments = Payment::get();
                $all_payments_total= $allPayments->sum('amount');

                //$allSubscriptions = Subscription::where('type','platform')->where('paid',1)->where('created_at', '<=' ,$endDate)->get();
                $allSubscriptions = Subscription::where('type','platform')->where('paid',1)->get();
                $all_subscriptions_total = $allSubscriptions->sum('partners_amount');

                $allAmont = $all_subscriptions_total - $all_payments_total;
                $partnerAmount = floor($allAmont * ($partner->percentage / 100));

                $paidAmount = PartnerPayment::where('partner_id',$partner->id)->get()->sum('amount');
                $partnerUnpaidAmount = $partnerAmount - $paidAmount;

                $partner->partner_amount = $partnerAmount;
                $partner->unpaid_amount = $partnerUnpaidAmount;

                return response()->json(['success' =>  $partner]);
            } else {
                return response()->json(['error' =>  'الشريك غير موجود']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }
    public function updatePartnersPercentage(Request $request)
    {
        $pageInfo['title']= 'تعديل نسبة الشركاء';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['partners-percentage'])){
            try {
                DB::beginTransaction ();
                // Validate the sum of percentages
                $totalPercentage = 0;
                foreach ($request->percentage as $key => $value) {
                    $totalPercentage += $value[0];
                }

                if ($totalPercentage != 100) {
                    return redirect()->back()->with('error', 'مجموع النسب يجب أن يكون 100٪');
                }
                foreach ($request->percentage as $key => $value) {
                    $partner = Partner::find($key);
                    $partner->percentage = $value[0];
                    $partner->save();
                }

                DB::commit();
                return to_route('partners.index')->with('message','تم تعديل نسبة الشركاء');
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return to_route('admin.partners.index')->with('error','حدث شيء ما خاطئ');
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

        /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $pageInfo['title']= 'إضافة شريك';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['partners-add'])){
            return view('admin.partners.create', compact('pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    public function store(PartnerRequest $request)
    {
        $pageInfo['title']= 'إضافة شريك';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['partners-add'])){
            try {
                DB::beginTransaction ();
                $user = Partner::create([
                    'name' => $request->name,
                    'email' => $request->email,
                    'phone'=>$request->phone,
                    'email_verified_at' => now(),
                    'password' => Hash::make($request->partner_password),
                    'email_verified_at' => now(),
                ]);
                if( $request->has('status') ){
                    $user->status="active";
                }else{
                    $user->status='inactive';
                }
                if ($request->hasFile('avatar')){
                    $user->addMediaFromRequest('avatar')->toMediaCollection('avatar');
                }
                $user->save();
                DB::commit();
                return to_route('partners.index')->with('message','تم اضافة الشريك بنجاح');
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                //dd($e->getMessage());
                return to_route('partners.index')->with('error','حدث شيء ما خاطئ');
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }
    public function show($id)
    {
        $pageInfo['title']= 'بروفايل الشريك';
        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['partners-show']))|| auth('partner')->check()){
            $partner = Partner::find($id);
            $subscriptions = $partner->subscriptions;
            $subscriptions_count = $subscriptions->sum('number_of_cards');

            $totalAmount = 0;
            foreach ($partner->subscriptions as $subscription) {
                $totalAmount += $subscription->pivot->amount;
            }
            //dd($totalAmount);
            return view('admin.partners.show', compact('pageInfo', 'partner','totalAmount','subscriptions','subscriptions_count'));
        }elseif(auth('partner')->check()){
            if($id == Auth::guard('partner')->user()->id ){
                $partner = Partner::find(Auth::guard('partner')->user()->id);
                $subscriptions = $partner->subscriptions;
                $subscriptions_count = $subscriptions->sum('number_of_cards');

                $totalAmount = 0;
                foreach ($partner->subscriptions as $subscription) {
                    $totalAmount += $subscription->pivot->amount;
                }
                return view('admin.partners.show', compact('pageInfo', 'partner','totalAmount','subscriptions','subscriptions_count'));
            }
            abort(404);
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
        /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        $pageInfo['title']= 'تعديل الشريك';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['partners-edit'])){
            $partner = Partner::find($id);
            return view('admin.partners.edit', compact('pageInfo', 'partner'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    public function update(PartnerRequest $request, $id)
    {
        $pageInfo['title']= 'تعديل الشريك';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['partners-edit'])){
            try {
                DB::beginTransaction ();
                $user=Partner::find($id);
                $user->update([
                    'name' => $request->name,
                    'email' => $request->email,
                    'phone'=>$request->phone,
                    'specialization'=>$request->specialization,
                ]);
                if( $request->has('status') ){
                    $user->status="active";
                }else{
                    $user->status='inactive';
                }

                if( $request->partner_password != null ){
                    $user->password=Hash::make($request->partner_password);
                }
                if ($request->hasFile('avatar')){
                    $user->clearMediaCollection('avatar');
                    $user->addMediaFromRequest('avatar')->toMediaCollection('avatar');
                } else {
                    if ($user->hasMedia('avatar')){
                        $user->clearMediaCollection('avatar');
                    }
                }
                $user->save();
                DB::commit();
                return to_route('partners.index')->with('message',trans('تم تعديل معلومات الشريك'));
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return to_route('partners.index')->with('error',trans('حدث شيء م خاطئ'));
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy( $id)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['partners-delete'])){
            try {
                $partner=Partner::find($id);
                if ($partner){
                    $partner->delete();
                    return response()->json([
                        'error'=>false,
                    ]);
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }


    }
}
