<?php

namespace App\Http\Controllers;

use Carbon\Carbon;
use App\Models\Partner;
use App\Models\Payment;
use App\Models\Subscription;
use Illuminate\Http\Request;
use App\Models\PartnerPayment;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\PartnerPaymentRequest;

class PartnerPaymentController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = 'دفعات الشركاء';
        $from = "";
        $to = "";


        if ((auth('admin')->check()) && auth('admin')->user()->hasAllPermissions(['partner-payment-list']) || auth('partner')->check()){
            $payments = PartnerPayment::all();
            $partners = Partner::all();
            $partner_id = '';
            return view('admin.partner-payments.index', compact('from','to','partner_id','partners','payments', 'pageInfo'));
        } elseif(auth('partner')->check()){
            $partner = Partner::where('id', Auth::guard('partner')->user()->id)->first();
            $payments = PartnerPayment::where('partner_id',$partner->id)->get();
            $partners = Partner::all();
            $partner_id = $partner->id;
            return view('admin.partner-payments.index', compact('from','to','partner_id','partners','payments', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function filter(Request $request)
    {
        $pageInfo['title'] = 'دفعات الشركاء';
        if ((auth('admin')->check() &&  Auth::guard('admin')->user()->hasAllPermissions(['partner-payment-list'])) || auth('partner')->check()){
            $partners = Partner::all();
            $query = PartnerPayment::query();
            $from = '';
            if (isset($request->from)) {
                $query->where('created_at', '>=' , $request->from);
                $from = $request->from;
            }
            $to = now();
            if (isset($request->to)) {
                $query->where('created_at', '<=' , $request->to);
                $to = $request->to;
            }
            $partner_id = '';
            if (isset($request->partner_id)) {
                $query->where('partner_id', $request->partner_id);
                $partner_id = $request->partner_id;
            }
            $payments = $query->get();
            return view('admin.partner-payments.index', compact('from','to','partner_id','partners','payments', 'pageInfo'));
        } elseif(auth('teacher')->check()){
            $partner = Partner::where('id', Auth::guard('partner')->user()->id)->first();
            $partners = Partner::all();
            $subscriptions = PartnerPayment::where('type','platform')->get();
            $query = PartnerPayment::query();
            $partner_id = $partner->id;
            $query->where('partner_id', $partner->id);
            $from = '';
            if (isset($request->from)) {
                $query->where('created_at', '>=' , $request->from);
                $from = $request->from;
            }
            $to = now();
            if (isset($request->to)) {
                $query->where('created_at', '<=' , $request->to);
                $to = $request->to;
            }

            $payments = $query->get();
            return view('admin.partner-payments.index', compact('from','to','partner_id','teachers','payments', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {

    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(PartnerPaymentRequest $request)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['partner-payment-add'])){
            try {
                $partner = Partner::where('id', $request->partner_id1)->first();
                if($partner){
                    DB::beginTransaction ();
                        $endDate = Carbon::now()->subMonth()->endOfMonth();
                      //  $allPayments = Payment::where('created_at', '<=' ,$endDate)->get();
                        $allPayments = Payment::all();
                        $all_payments_total= $allPayments->sum('amount');

                       // $allSubscriptions = Subscription::where('paid',1)->where('created_at', '<=' ,$endDate)->get();
                        $allSubscriptions = Subscription::where('paid',1)->get();
                        $all_subscriptions_total = $allSubscriptions->sum('partners_amount');

                        $allAmont = $all_subscriptions_total - $all_payments_total;
                        $partnerAmount = $allAmont * ($partner->percentage / 100);

                        $paidAmount = PartnerPayment::where('partner_id',$partner->id)->get()->sum('amount');
                        $partnerUnpaidAmount = $partnerAmount - $paidAmount;


                        $payment = PartnerPayment::create([
                            'partner_id' => $partner->id,
                            'unpaid_partner_amount'=> $partnerUnpaidAmount,
                            'total_partner_amount'=> $partnerAmount,
                            'amount'=> str_replace(',', '', $request->amount),
                            'remaining_unpaid_amount'=> $partnerUnpaidAmount - str_replace(',', '', $request->amount),
                        ]);
                        $payment->save();
                        /* $partner->update([
                            'unpaid_amount' =>$partner->unpaid_amount - str_replace(',', '', $request->amount),
                        ]); */
                    DB::commit();
                    return response()->json(['success' =>  $payment]);
                } else {
                    return response()->json(['error' =>  'الشريك غير موجود']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  $e->getMessage()]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للإضافة']);
        }

    }
    /**
     * Display the specified resource.
     */
    public function show($id)
    {

    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Request $request , $id)
    {

    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy($id)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['partner-payment-delete'])){
            try {
                $payment=PartnerPayment::find($id);
                $partner =Partner::find($payment->partner_id);
                if ($payment && $partner){
                    $partner->update([
                        'unpaid_amount' =>$partner->unpaid_amount + str_replace(',', '', $payment->amount),
                    ]);
                    $payment->delete();
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
                return response()->json([
                    'error'=>false,
                ]);
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }

    }
}
