<?php

namespace App\Http\Controllers;

use App\Models\Expense;
use App\Models\Payment;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\PaymentRequest;

class PaymentController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = trans('all.payments');

        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['payments-list']))|| auth('partner')->check()){
            $payments = Payment::where('expense_id', '!=', 1)->get();
            $expenses = Expense::where('id', '!=', 1)->get();
            $from ='';
            $to ='';
            $expense_id ='';
            $payments_total= $payments->sum('amount');
            return view('admin.payments.index', compact('from','to','payments','payments_total','expenses', 'pageInfo','expense_id'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function filter(Request $request)
    {
        $pageInfo['title'] = trans('all.payments');

        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['payments-list']))|| auth('partner')->check()){
            //$payments = Payment::where('expense_id', '!=', 1)->get();
            $expenses = Expense::where('id', '!=', 1)->get();

            $expense_id ='';



            $query = Payment::query();
            $query->where('expense_id', '!=', 1);
            $from = '';
            if (isset($request->from)) {
                $query->where('created_at', '>=' , $request->from);
                $from = $request->from;
            }
            $to = now();
            if (isset($request->to)) {
                $query->where('created_at', '<=' , $request->to);
                $to = $request->to;
            }
            $expense_id = '';
            if (isset($request->expense_id)) {
                $query->where('expense_id', $request->expense_id);
                $expense_id = $request->expense_id;
            }

            $payments = $query->get();
            $payments_total= $payments->sum('amount');
            return view('admin.payments.index', compact('from','to','payments','payments_total','expenses', 'pageInfo','expense_id'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(PaymentRequest $request)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['payments-add'])){
            try {
                $expense = Expense::where('id', $request->expense_id)->first();
                if($expense){
                    DB::beginTransaction ();
                        $amount = str_replace(',', '', $request->amount);
                        $payment = Payment::create([
                            'expense_id' => $expense->id,
                            'amount' => $amount,
                            'notes' => $request->notes,
                        ]);
                        $payment->save();
                    DB::commit();
                    return response()->json(['success' =>  $payment]);

                } else {
                    return response()->json(['error' =>  'نوع النفقة غير موجود']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للإضافة']);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(Payment $payment)
    {
        try {
            if($payment){
                return response()->json(['success' =>  $payment]);
            } else {
                return response()->json(['error' =>  'الدفعة غير موجودة']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Payment $payment)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(PaymentRequest $request, Payment $payment)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['payments-edit'])){
            try {
                if($payment){
                    $expense = Expense::where('id', $request->expense_id)->first();

                    if($expense){
                        DB::beginTransaction ();
                            $amount = str_replace(',', '', $request->amount);
                            $payment->update([
                                'expense_id' => $expense->id,
                                'amount' => $amount,
                                'notes' => $request->notes,
                            ]);
                            $payment->save();
                        DB::commit();
                        return response()->json(['success' =>  $payment]);
                    } else {
                        return response()->json(['error' =>  'نوع النفقة غير موجودة']);
                    }

                } else {
                    return response()->json(['error' =>  'الدفعة غير موجود']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للتعديل']);
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Payment $payment)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['payments-delete'])){
            try {
                if ($payment){
                    $payment->delete();
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
                return response()->json([
                    'error'=>false,
                ]);
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }
    }
}
