<?php

namespace App\Http\Controllers;

use Spatie\Permission\Models\Permission;
use Illuminate\Http\Request;
use Spatie\Permission\Models\Role;

class PermissionController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $pageInfo['title']= 'permissions';
        $permissions=Permission::all();
        return view('admin.permissions.index',compact('permissions','pageInfo'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $pageInfo['title']= 'permissions';
        return view('admin.permissions.create',compact('pageInfo'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $validated=$request->validate([
            'name'=>['required','min:3']
        ]);
        Permission::create($validated);
        return to_route('admin.permissions.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Permission  $permission
     * @return \Illuminate\Http\Response
     */
    public function show(Permission $permission)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Permission  $permission
     * @return \Illuminate\Http\Response
     */
    public function edit(Permission $permission)
    {
        $pageInfo['title']= 'permissions';
        $roles=Role::whereNotIn('name', ['admin'])->get();
        return view('admin.permissions.edit',compact('permission','roles','pageInfo'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Permission  $permission
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Permission $permission)
    {
        $validated=$request->validate([
            'name'=>['required','min:3']
        ]);
        $permission->update($validated);
        return to_route('admin.permissions.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Permission  $permission
     * @return \Illuminate\Http\Response
     */
    public function destroy(Permission $permission)
    {
        $permission->delete();
        return back();
    }
    public function assignRole(Request $request,Permission $permission)
    {
        if ($permission->hasRole($request->role)){
            return back()->with('message','The role is available');
        }else{
            $permission->assignRole($request->role);
            return back()->with('message','Role is added');
        }
    }
    public function removeRole(Permission $permission,Role $role){
        if ($permission->hasRole($role)){
            $permission->removeRole($role);
            return back()->with('message','The role is removed');
        }else{
            return back()->with('message','Role is not exist');
        }
    }
}
