<?php

namespace App\Http\Controllers;

use App\Models\Pos;
use App\Models\Card;
use App\Models\Partner;
use App\Models\Teacher;
use App\Models\Category;
use App\Models\Subscription;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\SubscriptionRequest;

class PosCardsController extends Controller
{
    public function index()
    {
        $pageInfo['title'] = 'الاشتراكات';
        $from = "";
        $to = "";
        $category_id = '';

        if ((auth('admin')->check() &&  Auth::guard('admin')->user()->hasAllPermissions(['pos-sales-list'])) ){
            $subscriptions = Subscription::where('type','pos')->get();
            $cards = Card::all();
            $pos = Pos::all();
            $teachers = Teacher::all();
            $categories = Category::all();
            $pos_id = '';
            return view('admin.pos-cards.index', compact('from','pos','to','categories','pos_id','category_id','teachers','subscriptions','cards', 'pageInfo'));
        } /* elseif(auth('teacher')->check()){
            $teacher = Teacher::where('id', Auth::guard('teacher')->user()->id)->first();
            $subscriptions = Subscription::whereIn('category_id', $teacher->card->pluck('id'))->get();
            $cards = $teacher->card;
            $pos = Pos::all();
            $categories = Category::all();

            $teachers = Teacher::all();
            $teacher_id = $teacher->id;
            return view('admin.pos-cards.index', compact('from','pos','to','categories','teacher_id','category_id','teachers','subscriptions','cards', 'pageInfo'));
        } */else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function filter(Request $request)
    {
        $pageInfo['title'] = 'الاشتراكات';


        if ((auth('admin')->check() &&  Auth::guard('admin')->user()->hasAllPermissions(['pos-sales-list'])) ){
            //$subscriptions = Subscription::where('type','pos')->get();
            $cards = Card::all();
            $teachers = Teacher::all();
            $pos = Pos::all();
            $categories = Category::all();
            $query = Subscription::query();
            $query->where('type','pos');
            $from = '';
            if (isset($request->from)) {
                $query->where('created_at', '>=' , $request->from);
                $from = $request->from;
            }
            $to = '';
            if (isset($request->to)) {
                $query->where('created_at', '<=' , $request->to);
                $to = $request->to;
            }
            $pos_id = '';
            if (isset($request->pos_id)) {
                $query->where('pos_id', $request->pos_id);
                $pos_id = $request->pos_id;
            }
            $category_id = '';
            if (isset($request->category_id)) {
                $query->where('category_id', $request->category_id);
                $category_id = $request->category_id;
            }
            $subscriptions = $query->get();
            return view('admin.pos-cards.index', compact('from','pos','to','categories','pos_id','category_id','teachers','subscriptions','cards', 'pageInfo'));
        } /* elseif(auth('teacher')->check()){
            $teacher = Teacher::where('id', Auth::guard('teacher')->user()->id)->first();
            //$subscriptions = Subscription::whereIn('category_id', $teacher->card->pluck('id'))->get();
            $pos = Pos::all();
            $teachers = Teacher::all();
            $categories = Category::all();
            $cards = Card::all();
            $teachers = Teacher::all();
            $query = Subscription::query();
            $query->where('type','pos');
            $query->whereIn('category_id', $teacher->card->pluck('id'));
            $from = '';
            if (isset($request->from)) {
                $query->where('created_at', '>' , $request->from);
                $from = $request->from;
            }
            $to = now();
            if (isset($request->to)) {
                $query->where('created_at', '<' , $request->to);
                $to = $request->to;
            }
            $teacher_id = '';
            if (isset($request->teacher_id)) {
                $query->where('teacher_id', $teacher->id);
                $teacher_id = $request->teacher_id;
            }
            $category_id = '';
            if (isset($request->category_id)) {
                $query->where('category_id', $request->category_id);
                $category_id = $request->category_id;
            }
            $subscriptions = $query->get();
            return view('admin.pos-cards.index', compact('from','pos','to','categories','teacher_id','category_id','teachers','subscriptions','cards', 'pageInfo'));
        } */else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    /* public function index()
    {
        $pageInfo['title'] = trans('all.subscriptions');

        if ((auth('admin')->check() &&  Auth::guard('admin')->user()->hasAllPermissions(['pos-sales-list'])) || auth('partner')->check()){
            $subscriptions = Subscription::where('type','pos')->get();
            $cards = Card::all();
            $pos = Pos::all();
            return view('admin.pos-cards.index', compact('subscriptions','cards', 'pos','pageInfo'));
        } elseif(auth('teacher')->check()){
           //  $teacher = Teacher::where('id', Auth::guard('teacher')->user()->id)->first();
            //$subscriptions = Subscription::whereIn('category_id', $teacher->card->pluck('id'))->get();
            $cards = Card::all();
            return view('admin.pos-cards.index', compact('subscriptions','cards', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    } */
        /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['pos-sales-add'])){
            try {
                $category = Category::where('id', $request->category_id)->first();
                $pos = pos::where('id', $request->pos_id)->first();
                if($category){
                    DB::beginTransaction ();
                        $number_of_cards = str_replace(',', '', $request->number_of_cards);
                        $total = $number_of_cards * $category->price_point_sale;
                        $subscription = Subscription::create([
                            'category_id' => $request->category_id,
                            'price' => $category->price_point_sale,
                            'number_of_cards'=>$request->number_of_cards,
                            'total'=> $total,
                            'pos_id' => $request->pos_id,
                            'type'=>'pos'
                        ]);

                        $subscription->save();
                        $pos->update([
                            'unpaid_amount' =>$pos->unpaid_amount + $total,
                            'total_amount' =>$pos->total_amount + $total,
                        ]);
                    DB::commit();
                    return response()->json(['success' =>  $subscription]);
                } else {
                    return response()->json(['error' =>  'البطاقة غير موجودة']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                //dd($e->getMessage());
                return response()->json(['error' => $e->getMessage()]);
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للإضافة']);
        }

    }
    public function show($id)
    {
        try {
            $subscription = Subscription::where('id', $id)->first();
            if($subscription){
               $cards = Card::where('teacher_id',$subscription->teacher_id)->where('category_id',$subscription->category_id)->with('courses')->get();
               //$cards = Card::where('teacher_id',$teacher->id)->where('category_id',$category)->with('courses')->get();
                $subscription->courses =  $cards;
                //dd($courses);
                return response()->json(['success' =>  $subscription]);
            } else {
                return response()->json(['error' =>  'العنصر غير موجود']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }
    /**
     * Update the specified resource in storage.
     */
    public function update(SubscriptionRequest $request, $id)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['pos-sales-edit'])){
            try {
                $subscription = Subscription::where('id', $id)->first();

                if($subscription){
                    if($subscription->paid){
                        return response()->json(['error' =>  'عذرا، لايمكنك التعديل تم الدفع']);
                    }
                     $old_amount = $subscription->total;
                    // $partners_amount = $total - $teacher_amount;

                    $category = Category::where('id', $subscription->category_id)->first();
                    //$teacher = Teacher::where('id', $subscription->teacher_id)->first();
                    $pos = pos::where('id', $request->pos_id)->first();

                    if($category){
                      //  dd($request->all());
                        DB::beginTransaction ();
                        $number_of_cards = str_replace(',', '', $request->number_of_cards);
                        $total = $number_of_cards * $category->price_point_sale;
                       // $teacher_amount = $number_of_cards * $category->price_point_sale * $category->teacher_percentage / 100;
                       // $partners_amount = $total - $teacher_amount;
                            $subscription->update([
                                    'category_id' => $category->id,
                                    //'card_id' => $card->id,
                                    'price' => $category->price_point_sale,
                                    'number_of_cards'=>$request->number_of_cards,
                                    'total'=> $total,
                                    //'teacher_id' => $teacher->id,
                                    //'teacher_percentage' => $card->category->teacher_percentage,
                                    //'teacher_amount' => $teacher_amount,
                                    //'partners_amount' => $partners_amount,
                                    'pos_id' => $request->pos_id,
                                    'type'=>'pos'
                                ]);

                            if( $request->has('paid') ){
                                $subscription->paid=1;
                                $subscription->paid_date= now();
                                /* $partners = Partner::all();
                                foreach ($partners as $key => $partner) {
                                    $partner->subscriptions()->attach($subscription->id, [
                                        'partner_percentage' => $partner->percentage,
                                        'amount' => ($partners_amount * $partner->percentage) / 100,
                                    ]);
                                }
                                $teacher->update([
                                    'unpaid_amount' =>$teacher->unpaid_amount + $teacher_amount,
                                    'total_amount' =>$teacher->total_amount + $teacher_amount,
                                ]); */
                            }else{
                                $subscription->paid=0;
                            }
                            $subscription->save();
                            $pos->update([
                                'unpaid_amount' =>$pos->unpaid_amount - $old_amount + $total,
                                'total_amount' =>$pos->total_amount - $old_amount + $total,
                            ]);
                        DB::commit();
                        return response()->json(['success' =>  $subscription]);
                    } else {
                        return response()->json(['error' =>  'البطاقة غير موجودة']);
                    }

                } else {
                    return response()->json(['error' =>  'الاشتراك غير موجود']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                dd($e->getMessage());
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للتعديل']);
        }
    }

    public function destroy( $id)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['pos-sales-delete'])){
            try {
                $subscription=Subscription::find($id);
                $pos = pos::where('id', $subscription->pos_id)->first();
                //dd($subscription->total );
                $pos->update([
                    'unpaid_amount' =>$pos->unpaid_amount - $subscription->total,
                    'total_amount' =>$pos->total_amount - $subscription->total,
                ]);
                if ($subscription->paid){
                    return response()->json(['error' =>  'عذراً لا يمكن الحذف ، لقد تم الدفع']);
                }elseif  ($subscription){
                    $subscription->delete();
                    return response()->json([
                        'error'=>false,
                    ]);
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }

            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }


    }
}
