<?php

namespace App\Http\Controllers;

use App\Models\Pos;
use App\Models\Category;
use Illuminate\Http\Request;
use App\Http\Requests\PosRequest;
use App\Models\PosPayment;
use App\Models\Subscription;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;

class PosController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = 'نقاط البيع';
        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['pos-list'])) ){
         $pos = Pos::all();

         return view('admin.pos.index', compact('pos', 'pageInfo'));
         }else{
             return view('admin.pages.not_allowed', compact('pageInfo'));
         }
    }
    public function getInfo($pos)
    {
        try {
            $pos = Pos::where('id', $pos)->first();
            if($pos){
                return response()->json(['success' =>  $pos]);
            } else {
                return response()->json(['error' =>  'نقطة البيع غير موجودة']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }
    public function getInfoAboutCategoty($pos , $category)
    {
        try {
            $pos = Pos::where('id', $pos)->first();
            $category = Category::where('id', $category)->first();
            if($pos ){
                $total_amount = Subscription::where('pos_id', $pos->id)->where('category_id', $category->id)->sum('total');
                $pos->total_amount = $total_amount;

                $paid_amount = PosPayment::where('pos_id', $pos->id)->where('category_id', $category->id)->sum('amount');
                $pos->paid_amount = $paid_amount;

                $pos->unpaid_amount = $total_amount - $paid_amount;
                return response()->json(['success' =>  $pos]);
            } else {
                return response()->json(['error' =>  'نقطة البيع غير موجودة']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }
    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $pageInfo['title']= 'إضافة نقطة بيع';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['pos-add'])){
            return view('admin.pos.create', compact('pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(PosRequest $request)
    {
        $pageInfo['title']= 'إضافة نقطة بيع';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['pos-add'])){
            try {
                DB::beginTransaction ();
                $pos = Pos::create([
                    'name' => $request->name,
                    'email' => $request->email,
                    'phone'=>$request->phone,
                    'address'=>$request->address,
                    'notes'=>$request->notes,
                ]);
                if( $request->has('status') ){
                    $pos->status="active";
                }else{
                    $pos->status='inactive';
                }
                $pos->save();
                DB::commit();
                return to_route('pos.index')->with('message',trans('تم اضافة نقطة بيع بنجاح'));
            }catch(\Exception $e){
                Log::info($e->getMessage());
                //dd($e->getMessage());
                DB::rollBack();
                return to_route('pos.index')->with('error',trans('حدث شيء ما خاطئ'));
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Display the specified resource.
     */
    public function show(Pos $pos)
    {
        $pageInfo['title']= 'بروفايل المندوب';
        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['pos-show']))){
            return view('admin.pos.show', compact('pageInfo', 'pos'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Pos $po)
    {
        $pageInfo['title']= 'تعديل نقطة بيع';
        $pos = $po;
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['pos-edit'])){
            return view('admin.pos.edit', compact('pageInfo', 'pos'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(PosRequest $request, Pos $po)
    {
        $pageInfo['title']= 'تعديل نقطة بيع';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['pos-edit'])){
            try {
                DB::beginTransaction ();
                $po->update([
                    'name' => $request->name,
                    'email' => $request->email,
                    'phone'=>$request->phone,
                    'address'=>$request->address,
                    'notes'=>$request->notes,
                ]);
                if( $request->has('status') ){
                    $po->status="active";
                }else{
                    $po->status='inactive';
                }
                $po->save();
                DB::commit();
                return to_route('pos.index')->with('message',trans('تم تعديل معلومات المندوب'));
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return to_route('pos.index')->with('error',trans('حدث شيء ما خاطئ'));
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Pos $po)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['pos-delete'])){
            try {
                if  ($po){
                    $po->delete();
                    return response()->json([
                        'error'=>false,
                    ]);
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }

    }
}
