<?php

namespace App\Http\Controllers;

use App\Models\Pos;
use App\Models\Category;
use App\Models\PosPayment;
use App\Models\Subscription;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\PosPaymentRequest;

class PosPaymentController extends Controller
{
   /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = 'دفعات نقاط البيع';
        $from = "";
        $to = "";
        $categories = Category::all();

        if ((auth('admin')->check()) && auth('admin')->user()->canAny(['pos-payment-list']) || auth('partner')->check()){
            $payments = PosPayment::all();
            $pos = Pos::all();
            $pos_id = '';
            return view('admin.pos-payments.index', compact('from','categories','to','pos_id','pos','payments', 'pageInfo'));
        } else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function filter(Request $request)
    {
        $pageInfo['title'] = 'دفعات نقاط البيع';
        if ((auth('admin')->check() &&  Auth::guard('admin')->user()->hasAllPermissions(['pos-payment-list'])) || auth('partner')->check()){
            $pos = Pos::all();
            $categories = Category::all();

            $query = PosPayment::query();
            $from = '';
            if (isset($request->from)) {
                $query->where('created_at', '>=' , $request->from);
                $from = $request->from;
            }
            $to = now();
            if (isset($request->to)) {
                $query->where('created_at', '<=' , $request->to);
                $to = $request->to;
            }
            $pos_id = '';
            if (isset($request->pos_id)) {
                $query->where('pos_id', $request->pos_id);
                $pos_id = $request->pos_id;
            }
            $payments = $query->get();
            return view('admin.pos-payments.index', compact('categories','from','to','pos_id','pos','payments', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {

    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(PosPaymentRequest $request)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['pos-payment-add'])){
            try {
               // dd($request->all());
               // dd(str_replace(',', '', $request->amount));
                $pos = Pos::where('id', $request->pos_id1)->first();
                $category = Category::where('id', $request->category_id)->first();
                if($pos && $category){
                    DB::beginTransaction ();
                    $total_amount = Subscription::where('pos_id', $pos->id)->where('category_id', $category->id)->sum('total');
                    $paid_amount = PosPayment::where('pos_id', $pos->id)->where('category_id', $category->id)->sum('amount');
                    $unpaid_amount = $total_amount - $paid_amount;

                        $payment = PosPayment::create([
                            'pos_id' => $pos->id,
                            'category_id' => $category->id,
                            'unpaid_pos_amount'=> $total_amount - $paid_amount,
                            'total_pos_amount'=> $total_amount,
                            'amount'=> str_replace(',', '', $request->amount),
                            'remaining_unpaid_amount'=>  $unpaid_amount - str_replace(',', '', $request->amount),
                        ]);
                        $payment->save();
                        $pos->update([
                            'unpaid_amount' =>$pos->unpaid_amount - str_replace(',', '', $request->amount),
                        ]);
                    DB::commit();
                    return response()->json(['success' =>  $payment]);
                } else {
                    return response()->json(['error' =>  'الفئة او نقطة البيع غير موجود']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  $e->getMessage()]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للإضافة']);
        }

    }
    /**
     * Display the specified resource.
     */
    public function show($id)
    {

    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Request $request , $id)
    {

    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy($id)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['pos-payment-delete'])){
            try {
                $payment=PosPayment::find($id);
                $pos =Pos::find($payment->pos_id);
                if ($payment && $pos){
                    $pos->update([
                        'unpaid_amount' =>$pos->unpaid_amount + str_replace(',', '', $payment->amount),
                    ]);
                    $payment->delete();
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
                return response()->json([
                    'error'=>false,
                ]);
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }

    }
}
