<?php

namespace App\Http\Controllers;

use Carbon\Carbon;
use App\Models\Expense;
use App\Models\Payment;
use App\Models\Subscription;
use Illuminate\Http\Request;
use App\Models\PartnerPayment;
use App\Models\TeacherPayment;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;

class ProfitController extends Controller
{
    public function index()
    {
        $pageInfo['title'] = 'الأرباح';

        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['profits-list']))|| auth('partner')->check()){
            //$salaries = Payment::where('expense_id', 1)->with('employee')->get();
            $salaries = Payment::where('expense_id', 1)->with('employee')->get();
            $salaries_total = $salaries->sum('amount');
            $payments = Payment::where('expense_id','<>', 1)->get();
            $payments_total= $payments->sum('amount');
            $subscriptions = Subscription::where('type','platform')->where('paid',1)->get();
            $subscriptions_total = $subscriptions->sum('partners_amount');
            $sales = Subscription::where('type','pos')->where('paid',1)->get();
            $sales_total = $sales->sum('partners_amount');
            $from = "2024-01-01T00:00:00";
            $to = now();
            //dd($salaries_total);
            return view('admin.profits.index', compact('from','to','payments','subscriptions','salaries','salaries_total','payments_total','subscriptions_total','sales_total', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function filter(Request $request)
    {
        $pageInfo['title'] = 'الأرباح';

        $from = $request->from;
        $to = $request->to;
        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['profits-list']))|| auth('partner')->check()){
            //$salaries = Payment::where('expense_id', 1)->with('employee')->get();
            $salaries = Payment::where('expense_id', 1)->where('created_at', '>=' ,$from)->where('created_at', '<=' ,$to)->with('employee')->get();
            $salaries_total = $salaries->sum('amount');
            $payments = Payment::where('expense_id','<>', 1)->where('created_at', '>=' ,$from)->where('created_at', '<=' ,$to)->get();
            $payments_total= $payments->sum('amount');
            $subscriptions = Subscription::where('type','platform')->where('paid',1)->where('paid_date', '>=' ,$from)->where('paid_date', '<=' ,$to)->get();
            $subscriptions_total = $subscriptions->sum('partners_amount');
            $sales = Subscription::where('type','pos')->where('paid',1)->where('paid_date', '>=' ,$from)->where('paid_date', '<=' ,$to)->get();
            $sales_total = $sales->sum('partners_amount');
            //dd($salaries_total);
            return view('admin.profits.index', compact('from','to','payments','subscriptions','salaries','salaries_total','payments_total','subscriptions_total','sales_total', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function monthlyProfits()
    {
        $pageInfo['title'] = 'الأرباح';

        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['profits-list']))|| auth('partner')->check()){
            // Define the start and end dates for each month in 2024
            $startDate = '';
            $endDate = '';

            // Loop through each month in 2024
            for ($year = date('Y'); $year >= 2024; $year--) {
                if( $year == date('Y')){
                    //$maxMonth = date('m');
                    $maxMonth = ltrim(date('m'), '0');
                } else {
                    $maxMonth = 12;
                }
                for ($month = $maxMonth; $month >= 1; $month--) {
                   // dd($maxMonth);
                    $monthlyData[$year][$month]=[];
                    // Set the start and end dates for the current month
                    $startDate = date('Y-m-01', strtotime("$year-$month-01"));
                    $endDate = date('Y-m-t', strtotime("$year-$month-01"));

                    // Retrieve data from the payments table for the current month

                    $payments = Payment::whereBetween('created_at', [$startDate, $endDate])->get();
                    $payments_total= $payments->sum('amount');
                    // Retrieve data from the subscriptions table for the current month
                    $subscriptions = Subscription::where('type','platform')->where('paid',1)->whereBetween('created_at', [$startDate, $endDate])->get();
                    $subscriptions_total = $subscriptions->sum('total');
                    // Retrieve data from the teacher_payments table for the current month

                    $teacher_payments = TeacherPayment::whereBetween('created_at', [$startDate, $endDate])->get();
                    $total_teacher_payments = $teacher_payments->sum('amount');
                    // Retrieve data from the partner_payments table for the current month
                    $partner_payments = PartnerPayment::whereBetween('created_at', [$startDate, $endDate])->get();
                    $total_partner_payments = $partner_payments->sum('amount');
                    // Process or display the retrieved data for the current month as needed
                    $monthlyData[$year][$month]['subscriptions_total']=$subscriptions_total;
                    $monthlyData[$year][$month]['total_payments']=$payments_total;
                    $monthlyData[$year][$month]['total_teacher_payments']=$total_teacher_payments;
                    $monthlyData[$year][$month]['total_partner_payments']=$total_partner_payments;


                    // cash
                    $allPayments = Payment::where('created_at', '<=' ,$endDate)->get();
                    $all_payments_total= $allPayments->sum('amount');

                    $allSubscriptions = Subscription::where('type','platform')->where('paid',1)->where('created_at', '<=' ,$endDate)->get();
                    $all_subscriptions_total = $allSubscriptions->sum('total');

                    $allTeachersPayments = TeacherPayment::where('created_at', '<=' ,$endDate)->get();
                    $all_teachers_total = $allTeachersPayments->sum('amount');

                    $allPartnersPayments = PartnerPayment::where('created_at', '<=' ,$endDate)->get();
                    $all_partners_total = $allPartnersPayments->sum('amount');
                    $monthlyData[$year][$month]['cash']=$all_subscriptions_total - ($all_payments_total + $all_teachers_total + $all_partners_total );

                }
            }

            //dd($monthlyData);
            $from = "2024-01-01T00:00:00";
            $to = now();
            return view('admin.profits.monthly', compact('from','to','monthlyData', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function monthlyProfitsData($year, $month)
    {
        $pageInfo['title'] = 'الأرباح';

        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['profits-list']))|| auth('partner')->check()){
                    $monthlyData=[];
                    $startDate = Carbon::create($year, $month, 1)->startOfMonth();
                    $endDate = Carbon::create($year, $month, 1)->endOfMonth();

                    $payments = Payment::where('expense_id','<>', 1)->whereBetween('created_at', [$startDate, $endDate])->get();
                    $payments_total= $payments->sum('amount');

                    $salaries = Payment::where('expense_id', 1)->with('employee')->whereBetween('created_at', [$startDate, $endDate])->get();
                    $salaries_total = $salaries->sum('amount');
                  //  dd($salaries);
                    $subscriptions = Subscription::where('type','platform')->where('paid',1)->whereBetween('created_at', [$startDate, $endDate])->get();
                    $subscriptions_total = $subscriptions->sum('total');

                    $teacher_payments = TeacherPayment::whereBetween('created_at', [$startDate, $endDate])->get();
                    $total_teacher_payments = $teacher_payments->sum('amount');

                    $partner_payments = PartnerPayment::whereBetween('created_at', [$startDate, $endDate])->get();
                    $total_partner_payments = $partner_payments->sum('amount');

                    $monthlyData['month']=$month;
                    $monthlyData['year']=$year;
                    $monthlyData['subscriptions_total']=$subscriptions_total;
                    $monthlyData['payments_total']=$payments_total;
                    $monthlyData['salaries_total']=$salaries_total;
                    $monthlyData['total_teacher_payments']=$total_teacher_payments;
                    $monthlyData['total_partner_payments']=$total_partner_payments;
                    $date = \Carbon\Carbon::create($year, $month, 1);
                    $formattedDate = $date->translatedFormat('F Y');
                    $monthlyData['date']=$formattedDate;
                    // dd($monthlyData);

                    $allPayments = Payment::where('created_at', '<=' ,$endDate)->get();
                    $all_payments_total= $allPayments->sum('amount');

                    $allSubscriptions = Subscription::where('paid',1)->where('created_at', '<=' ,$endDate)->get();
                    $all_subscriptions_total = $allSubscriptions->sum('total');

                    $allTeachersPayments = TeacherPayment::where('created_at', '<=' ,$endDate)->get();
                    $all_teachers_total = $allTeachersPayments->sum('amount');

                    $allPartnersPayments = PartnerPayment::where('created_at', '<=' ,$endDate)->get();
                    $all_partners_total = $allPartnersPayments->sum('amount');
                    $monthlyData['cash']=$all_subscriptions_total - ($all_payments_total + $all_teachers_total + $all_partners_total );

            return view('admin.profits.month-details', compact('monthlyData','payments','salaries','teacher_payments','partner_payments','subscriptions', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    /* public function monthlyProfits()
    {
        $pageInfo['title'] = 'الأرباح';

        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['profits-list']))|| auth('partner')->check()){
            $salaries = Payment::where('expense_id', 1)->with('employee')->get();
            $salaries_total = $salaries->sum('amount');
            $payments = Payment::where('expense_id','<>', 1)->get();
            $payments_total= $payments->sum('amount');
            $subscriptions = Subscription::where('type','platform')->where('paid',1)->get();
            $subscriptions_total = $subscriptions->sum('partners_amount');
            $sales = Subscription::where('type','pos')->where('paid',1)->get();
            $sales_total = $sales->sum('partners_amount');
            $from = "2024-01-01T00:00:00";
            $to = now();
            return view('admin.profits.monthly', compact('from','to','payments','subscriptions','salaries','salaries_total','payments_total','subscriptions_total','sales_total', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    } */

}
