<?php

namespace App\Http\Controllers;

use App\Models\Order;
use App\Models\Region;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use App\Http\Requests\RegionRequest;
use Illuminate\Support\Facades\Auth;

class RegionController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = 'المناطق';

        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['regions-list'])) || auth('partner')->check()){
            $regions = Region::all();
            return view('admin.regions.index', compact('regions', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(RegionRequest $request)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['regions-add'])){
            try {
                DB::beginTransaction ();
                    $region = Region::create([
                        'title' => $request->title,
                    ]);
                    $region->save();
                DB::commit();
                return response()->json(['success' =>  $region]);
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للإضافة']);
        }

    }

    /**
     * Display the specified resource.
     */
    public function show(Region $region)
    {
        try {
            if($region){
                return response()->json(['success' =>  $region]);
            } else {
                return response()->json(['error' =>  'المنطقة غير موجودة']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Region $region)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(RegionRequest $request, Region $region)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['regions-edit'])){
            try {
                if($region){
                    DB::beginTransaction ();
                        $region->update([
                            'title' => $request->title
                        ]);
                        $region->save();
                    DB::commit();
                    return response()->json(['success' =>  $region]);
                } else {
                    return response()->json(['error' =>  'المنطقة غير موجود']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للتعديل']);
        }

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Region $region)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['regions-delete'])){
            try {
               /*  $order=Order::where('region_id',$region->id)->first();
                if ($order){
                    return response()->json(['error' =>  'عذراً لا يمكن الحذف ، يوجد طلبات لهذه المنطقة']);
                }else */ if ($region){
                    $region->delete();
                    return response()->json([
                        'error'=>false,
                    ]);
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }


    }
}
