<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Requests\RoleRequest;
use Illuminate\Support\Facades\DB;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use Spatie\Permission\Models\Permission;

class RoleController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $pageInfo['title'] = 'الأدوار';
        if (auth('admin')->check() &&  Auth::guard('admin')->user()->canAny(['role-list'])){
            $roles=Role::where('guard_name','admin')->get();
            $permissions = Permission::where('guard_name','admin')
                        ->get()
                        ->groupBy('section');
            return view('admin.roles.index',compact('roles','pageInfo','permissions'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $pageInfo['title'] = 'إضافة دور';
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['role-add'])){
            $permissions = Permission::where('guard_name','admin')
            ->get()
            ->groupBy('section');
            return view('admin.roles.create',compact('permissions'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(RoleRequest $request)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['role-add'])){
            try {
                $role=Role::create($request->all());
                $role->guard_name='admin';
                    if(isset($request->permissions)) {
                        if (is_array($request->permissions)) {
                            $permissions = array();
                            foreach ($request->permissions as $value) {
                                $permission = Permission::where('id',$value)->where('guard_name','admin')->first();
                                array_push($permissions, $permission->name);
                            }
                            $role->syncPermissions($permissions);
                            $role->save();
                        }
                    }
                    return redirect()->route('roles.index')->with('success', 'تمت الاضافة بنجاح');
                }catch (\Exception $e){
                    Log::info($e->getMessage());
                    DB::rollBack();
                    return redirect()->back()->with('error',trans('حدث خطأ  ما'));
                }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Role  $role
     * @return \Illuminate\Http\Response
     */
    public function show(Role $role)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Role  $role
     * @return \Illuminate\Http\Response
     */
    public function edit(Role $role)
    {
        $pageInfo['title'] = 'تعديل الدور';
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['role-edit'])){
            $rolePermissions = $role->permissions;
            $permissions = Permission::where('guard_name','admin')
                        ->get()
                        ->groupBy('section');
            return view('admin.roles.edit',compact('role','rolePermissions','permissions'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Role  $role
     * @return \Illuminate\Http\Response
     */
    public function update(RoleRequest $request, Role $role)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['role-edit'])){
            try {
                DB::beginTransaction ();
                $validated=$request->validate([
                    'name'=>['required','min:3']
                ]);
                //dd($request->permissions);
                $role->update($validated);
                if(isset($request->permissions)) {
                    if (is_array($request->permissions)) {
                        $permissions = array();
                        foreach ($request->permissions as $value) {
                            $permission = Permission::where('id',$value)->where('guard_name','admin')->first();
                            array_push($permissions, $permission->name);
                        }
                        $role->syncPermissions($permissions);
                        $role->save();
                    }
                }
                return redirect()->route('roles.index')->with('success', 'تم التعديل بنجاح');
                DB::commit();
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return redirect()->back()->with('error',trans('حدث خطأ  ما'));
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }


    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Role  $role
     * @return \Illuminate\Http\Response
     */
    public function destroy(Role $role)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['role-delete'])){
            try {
                if ($role->id==1){
                    return response()->json([
                        'error'=>true,
                    ]);
                }
                $role->delete();
                return response()->json([
                    'error'=>false,
                ]);
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }

    }
    public function givePermission(Request $request,Role $role)
    {
        if ($role->hasPermissionTo($request->permission)){
            return back()->with('message',trans('all.permissionAvailable'));
        }else{
            $role->givePermissionTo($request->permission);
            return back()->with('message',trans('all.permissionAdded'));
        }
    }
    public function revokePermission(Role $role,Permission $permission){
        try{
        if ($role->hasPermissionTo($permission)){
            $role->revokePermissionTo($permission);

            return response()->json([
                'error'=>false,
                'message'=>'1',
            ]);
        }else{
            return response()->json([
                'error'=>false,
                'message'=>'2',
            ]);
        }
        }catch (\Exception $e){
            return response()->json([
                'error'=>true,
                'result'=>$e->getMessage(),
            ]);
        }
    }
    /* public function assignRole(Request $request,User $user)
    {
        if ($user->hasRole($request->role)){
            return back()->with('message','The role is available');
        }else{
            $user->assignRole($request->role);
            return back()->with('message','Role is added');
        }
    }
    public function removeRole(User $user,Role $role){
        if ($user->hasRole($role)){
            $user->removeRole($role);
            return back()->with('message','The role is removed');
        }else{
            return back()->with('message','Role is not exist');
        }
    } */
}
