<?php

namespace App\Http\Controllers;

use App\Models\Expense;
use App\Models\Payment;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\SalaryRequest;
use App\Models\Employee;

class SalaryController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = 'الرواتب';

        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['salaries-list']))|| auth('partner')->check()){
            $payments = Payment::where('expense_id', 1)->with('employee')->get();
            $expenses = Expense::all();
            $employees = Employee::where('status','active')->get();
            return view('admin.salaries.index', compact('payments','expenses','employees', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(SalaryRequest $request)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['salaries-add'])){
            try {
                $employee = Employee::where('id', $request->employee_id)->first();
                if($employee){
                    DB::beginTransaction ();
                        $amount = str_replace(',', '', $request->amount);
                        $payment = Payment::create([
                            'expense_id' => 1,
                            'employee_id' => $request->employee_id,
                            'amount' => $amount,
                            'notes' => $request->notes,
                        ]);
                        $payment->save();
                        $employee->update([
                            'notes'=>$request->employee_notes,
                        ]);
                    DB::commit();
                    return response()->json(['success' =>  $payment]);
                } else {
                    return response()->json(['error' =>  'الموظف غير موجود']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للإضافة']);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show( $id)
    {
        try {
            $payment = Payment::where('id', $id)
                        ->with('employee.section')
                        ->first();
            if($payment){
                return response()->json(['success' =>  $payment]);
            } else {
                return response()->json(['error' =>  'الراتب غير موجود']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }
    public function employeeInfo(Employee $employee)
    {
        try {
            $employee = Employee::where('id', $employee->id)->with('section')->first();
            if($employee){
                return response()->json(['success' =>  $employee]);
            } else {
                return response()->json(['error' =>  'الموظف غير موجود']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Payment $payment)
    {

    }

    /**
     * Update the specified resource in storage.
     */
    public function update(SalaryRequest $request, Payment $salary)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['salaries-edit'])){
            try {
                $employee = Employee::where('id', $request->employee_id)->first();
                if($employee){
                    DB::beginTransaction ();
                        $amount = str_replace(',', '', $request->amount);

                        $salary->update([
                            'expense_id' => 1,
                            'employee_id' => $request->employee_id,
                            'amount' => $amount,
                            'notes' => $request->notes,
                        ]);
                        $employee->update([
                            'notes'=>$request->employee_notes,
                        ]);
                    DB::commit();
                    return response()->json(['success' =>  $salary]);
                } else {
                    return response()->json(['error' =>  'الموظف غير موجود']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للتعديل']);
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Payment $salary)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['salaries-delete'])){
            try {
                if ($salary){
                    $salary->delete();
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
                return response()->json([
                    'error'=>false,
                ]);
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }
    }
}
