<?php

namespace App\Http\Controllers;

use App\Models\Section;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\SectionRequest;

class SectionController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = trans('all.sections');

        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['sections-list']))|| auth('partner')->check()){
            $sections = Section::all();
            return view('admin.sections.index', compact('sections', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(SectionRequest $request)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['sections-add'])){
            try {
                DB::beginTransaction ();
                    $section = Section::create([
                        'title' => $request->title,
                    ]);
                    $section->save();
                DB::commit();
                return response()->json(['success' =>  $section]);
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للإضافة']);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(Section $section)
    {
        try {
            if($section){
                return response()->json(['success' =>  $section]);
            } else {
                return response()->json(['error' =>  'القسم غير موجود']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Section $section)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Section $section)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['sections-edit'])){
            try {
                if($section){
                    DB::beginTransaction ();
                        $section->update([
                            'title' => $request->title
                        ]);
                        $section->save();
                    DB::commit();
                    return response()->json(['success' =>  $section]);
                } else {
                    return response()->json(['error' =>  'القسم غير موجود']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للتعديل']);
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Section $section)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['sections-delete'])){
            try {
                if ($section->employees->count() > 0 ){
                    return response()->json(['error' =>  'عذراً لا يمكن الحذف ، يوجد موظفين مرتبطين بهذا القسم']);
                }elseif  ($section){
                    $section->delete();
                    return response()->json([
                        'error'=>false,
                    ]);
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }

        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }

    }
}
