<?php

namespace App\Http\Controllers;

use App\Models\Subject;
use App\Models\Teacher;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\SubjectRequest;

class SubjectController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = trans('all.subjects');

        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['subjects-list'])) || auth('partner')->check()){
            $subjects = Subject::all();
            return view('admin.subjects.index', compact('subjects', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(SubjectRequest $request)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['subjects-add'])){
            try {
                DB::beginTransaction ();
                    $subject = Subject::create([
                        'title' => $request->title,
                    ]);
                    $subject->save();
                DB::commit();
                return response()->json(['success' =>  $subject]);
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للإضافة']);
        }

    }

    /**
     * Display the specified resource.
     */
    public function show(Subject $subject)
    {
        try {
            if($subject){
                return response()->json(['success' =>  $subject]);
            } else {
                return response()->json(['error' =>  'المادة غير موجودة']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Subject $subject)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Subject $subject)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['subjects-edit'])){
            try {
                if($subject){
                    DB::beginTransaction ();
                        $subject->update([
                            'title' => $request->title
                        ]);
                        $subject->save();
                    DB::commit();
                    return response()->json(['success' =>  $subject]);
                } else {
                    return response()->json(['error' =>  'المادة غير موجود']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  'حدث شيء ما خاطئ']);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للتعديل']);
        }

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Subject $subject)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['subjects-delete'])){
            try {
                $teacher=Teacher::where('specialization',$subject->id)->first();
                if ($teacher){
                    return response()->json(['error' =>  'عذراً لا يمكن الحذف ، يوجد معلمين مختصين بهذه المادة']);
                }elseif  ($subject){
                    $subject->delete();
                    return response()->json([
                        'error'=>false,
                    ]);
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }


    }
}
