<?php

namespace App\Http\Controllers;

use App\Models\Card;
use App\Models\Subscription;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\SubscriptionRequest;
use App\Models\Category;
use App\Models\Partner;
use App\Models\Teacher;

class SubscriptionController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = 'الاشتراكات';
        $from = "";
        $to = "";
        $category_id = '';
        $card_id = '';
        $cards = [];
        if ((auth('admin')->check() &&  Auth::guard('admin')->user()->hasAllPermissions(['subscriptions-list'])) || auth('partner')->check()){
            $subscriptions = Subscription::where('type','platform')->get();
            $subscriptions_count = $subscriptions->sum('number_of_cards');
            $categories = Category::all();
            $teachers = Teacher::all();
            $teacher_id = '';
            return view('admin.subscriptions.index', compact('subscriptions_count','from','to','teacher_id','card_id','category_id','teachers','subscriptions','cards','categories', 'pageInfo'));
        } elseif(auth('teacher')->check()){
            $teacher = Teacher::where('id', Auth::guard('teacher')->user()->id)->first();
           // $subscriptions = Subscription::whereIn('card_id', $teacher->card->pluck('id'))->get();
            $subscriptions = Subscription::where('teacher_id',$teacher->id)->get();
            $subscriptions_count = $subscriptions->sum('number_of_cards');
            $categories = Category::all();

            $teachers = Teacher::all();
            $teacher_id = $teacher->id;
            return view('admin.subscriptions.index-teacher', compact('subscriptions_count','from','to','teacher_id','category_id','card_id','teachers','subscriptions','cards','categories', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function filter(Request $request)
    {
        $pageInfo['title'] = 'الاشتراكات';


        if ((auth('admin')->check() &&  Auth::guard('admin')->user()->hasAllPermissions(['subscriptions-list'])) || auth('partner')->check()){
           // $subscriptions = Subscription::where('type','platform')->get();

            $cards = Card::all();
            $categories = Category::all();
            $query = Subscription::query();
            $query->where('type','platform');
            $from = '';
            if (isset($request->from)) {
                $query->where('created_at', '>=' , $request->from);
                $from = $request->from;
            }
            $to = now();
            if (isset($request->to)) {
                $query->where('created_at', '<=' , $request->to);
                $to = $request->to;
            }
            $teacher_id = '';
            if (isset($request->teacher_id)) {
                $query->where('teacher_id', $request->teacher_id);
                $teacher_id = $request->teacher_id;
            }
            $category_id = '';
            if (isset($request->category_id)) {
                $query->where('category_id', $request->category_id);
                $category_id = $request->category_id;

                $category = Category::where('id', $category_id)->first();
                if($category){
                    $teachers = Teacher::whereHas('cards', function ($query) use ($category) {
                        $query->where('category_id', $category->id);
                    })->get();
                } else {
                    $teachers = Teacher::all();
                }
            } else {
                $teachers = Teacher::all();
            }
            if (isset($request->category_id) && $request->category_id !== null &&
                isset($request->teacher_id) && $request->teacher_id !== null) {
                $cards = Card::where('teacher_id',$request->teacher_id)->where('category_id',$request->category_id)->with(['courses'])->get();
            } else {
                $cards = [];
            }

            $card_id = '';
            if (isset($request->card_id)) {
                $query->where('card_id', $request->card_id);
                $card_id = $request->card_id;
            }
            $subscriptions = $query->get();
            $subscriptions_count = $subscriptions->sum('number_of_cards');
            return view('admin.subscriptions.index', compact('subscriptions_count','from','to','teacher_id','category_id','card_id','teachers','subscriptions','cards','categories', 'pageInfo'));
        } elseif(auth('teacher')->check()){
            $teacher = Teacher::where('id', Auth::guard('teacher')->user()->id)->first();
            //$subscriptions = Subscription::whereIn('card_id', $teacher->card->pluck('id'))->get();
            $categories = Category::all();
            $subscriptions = Subscription::where('type','platform')->get();
            $cards = Card::all();
            $teachers = Teacher::all();
            $query = Subscription::query();
            $query->where('type','platform');
            $teacher_id = $teacher->id;
            //$query->whereIn('card_id', $teacher->card->pluck('id'));
            $from = '';
            if (isset($request->from)) {
                $query->where('created_at', '>=' , $request->from);
                $from = $request->from;
            }
            $to = now();
            if (isset($request->to)) {
                $query->where('created_at', '<=' , $request->to);
                $to = $request->to;
            }

            $query->where('teacher_id', $teacher_id);

            if (isset($request->category_id)) {
                $query->where('category_id', $request->category_id);
                $category_id = $request->category_id;

                $category = Category::where('id', $category_id)->first();
                if($category){
                    $cards = Card::where('teacher_id',$teacher_id)->where('category_id',$request->category_id)->with(['courses'])->get();
                } else {
                    $cards = [];
                }
            }
            $card_id = '';
            if (isset($request->card_id)) {
                $query->where('card_id', $request->card_id);
                $card_id = $request->card_id;
            }
            $subscriptions = $query->get();
            $subscriptions_count = $subscriptions->sum('number_of_cards');

            return view('admin.subscriptions.index-teacher', compact('subscriptions_count','from','to','teacher_id','category_id','card_id','teachers','subscriptions','cards','categories', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $pageInfo['title']= 'انشاء اشتراك';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['subscriptions-add'])){

            $cards = Card::all();
            $teachers = Teacher::all();
            $categories = Category::all();

            return view('admin.subscriptions.create', compact('pageInfo','categories','cards','teachers'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(SubscriptionRequest $request)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['subscriptions-add'])){
            try {
                $card = Card::where('id', $request->card_id)->first();
                $teacher = Teacher::where('id', $card->teacher->id)->first();
                if($card){
                    DB::beginTransaction ();
                        $number_of_cards = str_replace(',', '', $request->number_of_cards);
                        $data = [
                            'category_id' => $request->category_id,
                            'card_id' => $card->id,
                            'price' => $card->category->price,
                            'number_of_cards'=>$number_of_cards,
                            'teacher_id' =>  $card->teacher->id,
                            'type'=>'platform',
                            'paid'=>1,
                            'paid_date'=>now(),
                        ];
                        if($card->category->type == 'amount'){
                            $data['teacher_percentage']=$card->category->teacher_amount;
                        } else {
                            $data['teacher_percentage']=$card->category->teacher_percentage;
                        }
                        if( $request->has('discount') && $card->category->type == 'percentage' ){
                            $discount_value = str_replace(',', '', $request->discount_value);
                            $total = ($number_of_cards * $card->category->price) - $discount_value;

                            $teacher_amount = $total * $card->category->teacher_percentage / 100;

                            $partners_amount = $total - $teacher_amount;
                            $data['total'] = $total;
                            $data['discount'] = 1;
                            $data['price_befor_discount'] = $number_of_cards * $card->category->price;
                        } else {
                            $total = $number_of_cards * $card->category->price;
                            if($card->category->type == 'amount'){
                                $teacher_amount = $card->category->teacher_amount * $number_of_cards;
                            } else {
                                $teacher_amount = $total * $card->category->teacher_percentage / 100;
                            }
                            $partners_amount = $total - $teacher_amount;
                            $data['total'] = $total;
                            $data['discount'] = 0;
                            $data['price_befor_discount'] = null;
                        }
                        $data['teacher_amount'] = $teacher_amount;
                        $data['partners_amount'] = $partners_amount;
                        $data['created_at'] = $request->created_at;
                        $subscription = Subscription::create($data);
                        //return $data;
                        /*
                        $total = $number_of_cards * $card->category->price;
                        $teacher_amount = $number_of_cards * $card->category->price * $card->category->teacher_percentage / 100;
                        $partners_amount = $total - $teacher_amount;

                        $subscription = Subscription::create([
                            'category_id' => $request->category_id,
                            'card_id' => $card->id,
                            'price' => $card->category->price,
                            'number_of_cards'=>$number_of_cards,
                            'total'=>$total,
                            'teacher_id' =>  $card->teacher->id,
                            'teacher_percentage' => $card->category->teacher_percentage,
                            'type'=>'platform',
                            'paid'=>1,
                            'paid_date'=>now(),
                            'teacher_amount' => $teacher_amount,
                            'partners_amount' => $partners_amount
                        ]); */
                        $subscription->save();

                        $partners = Partner::all();
                        foreach ($partners as $key => $partner) {
                            $partner->subscriptions()->attach($subscription->id, [
                                'partner_percentage' => $partner->percentage,
                                'amount' => ($partners_amount * $partner->percentage) / 100,
                            ]);

                           /*  $partner->update([
                                'unpaid_amount' =>$partner->unpaid_amount + (($partners_amount * $partner->percentage) / 100),
                                'total_amount' =>$partner->total_amount +(($partners_amount * $partner->percentage) / 100),
                            ]); */
                        }

                        $teacher->update([
                            'unpaid_amount' =>$teacher->unpaid_amount + $teacher_amount,
                            'total_amount' =>$teacher->total_amount + $teacher_amount,
                        ]);
                    DB::commit();
                    return redirect()->route('subscriptions.index')->with('success', 'تم اضافة الاشتراك بنجاح');
                    //return response()->json(['success' =>  $subscription]);
                } else {
                    return redirect()->route('subscriptions.create')->with('error' ,  'البطاقة غير موجودة');
                   // return response()->json(['error' =>  'البطاقة غير موجودة']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return redirect()->route('subscriptions.create')->with('error' ,  $e->getMessage());
               // return response()->json(['error' =>  $e->getMessage()]);
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
            //return response()->json(['error' =>  'لا تملك الإذن للإضافة']);
        }

    }

    /**
     * Display the specified resource.
     */
    public function show($id)
    {
        try {
            $subscription = Subscription::where('id', $id)->first();
            if($subscription){
                return response()->json(['success' =>  $subscription]);
            } else {
                return response()->json(['error' =>  'الاشتراك غير موجود']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        $pageInfo['title']= 'تعديل الاشتراك';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['subscriptions-edit'])){
            $subscription = Subscription::find($id);
            $cards = Card::all();
            $teachers = Teacher::all();
            $categories = Category::all();

            return view('admin.subscriptions.edit', compact('pageInfo', 'subscription','categories','cards','teachers'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

     public function update(Request $request, Subscription $subscription)
    {
        $pageInfo['title']= 'تعديل الاشتراك';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['subscriptions-edit'])){
            try {
                //dd($request->created_at);
                if($subscription){
                    DB::beginTransaction ();
                        $data = [
                            'created_at'=>$request->created_at,
                        ];
                        $subscription->update($data);
                    DB::commit();
                    return to_route('subscriptions.index')->with('message','تم تعديل معلومات الاشتراك');
                } else {
                    return redirect()->back()->with('error', 'الاشتراك غير موجود');
                }

            }catch(\Exception $e){
                Log::info($e->getMessage());
                //dd($e->getMessage());
                DB::rollBack();
                return to_route('admin.categories.index')->with('error','حدث شيء ما خاطئ');
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }


    /**
     * Remove the specified resource from storage.
     */
    public function destroy($id)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['subscriptions-delete'])){
            try {
                $subscription=Subscription::find($id);
                $teacher =Teacher::find($subscription->teacher_id);
                if ($subscription && $teacher){
                    if($subscription->teacher_amount - $teacher->unpaid_amount > 0){
                        return response()->json([
                            'error'=>'عذرا لا يمكنك الحذف المبلغ يبدو انه تم تسديد المبلغ للمعلم',
                        ]);
                    }
                    /* $partners = Partner::all();
                        foreach ($partners as $key => $partner) {
                            $partner->update([
                                'unpaid_amount' =>$partner->unpaid_amount - (($subscription->partners_amount * $partner->percentage) / 100),
                                'total_amount' =>$partner->total_amount - (($subscription->partners_amount * $partner->percentage) / 100),
                            ]);
                        } */
                    $teacher->update([
                        'unpaid_amount' =>$teacher->unpaid_amount - $subscription->teacher_amount,
                        'total_amount' =>$teacher->total_amount - $subscription->teacher_amount,
                    ]);

                    $subscription->partners()->detach();
                    $subscription->delete();
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
                return response()->json([
                    'error'=>false,
                ]);
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }

    }
}
