<?php

namespace App\Http\Controllers;

use App\Models\Admin;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Spatie\Permission\Models\Role;
use App\Http\Requests\AdminRequest;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class SupervisorController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = 'المشرفون';
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['super-list'])){
        $admins = Admin::all();
        return view('admin.supervisors.index', compact('admins', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $pageInfo['title']= 'إضافة مشرف';
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['super-add'])){
            $roles = Role::where('guard_name', 'admin')->get();
            return view('admin.supervisors.create', compact('pageInfo', 'roles'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(AdminRequest $request)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['super-add'])){
            try {
                DB::beginTransaction ();
                $user = Admin::create([
                    'name' => $request->name,
                    'email' => $request->email,
                    'phone'=>$request->phone,
                    'email_verified_at' => now(),
                    'password' => Hash::make($request->password),
                    'email_verified_at' => now(),
                ]);
                if( $request->has('status') ){
                    $user->status="active";
                }else{
                    $user->status='inactive';
                }
                if ($request->hasFile('avatar')){
                    $user->addMediaFromRequest('avatar')->toMediaCollection('avatar');
                }
                if(isset($request->roles_name)) {
                    if (is_array($request->roles_name)) {
                        $roles = array();
                        foreach ($request->roles_name as $value) {
                            $role = Role::where('id',$value)->where('guard_name','admin')->first();
                            $user->assignRole([$role->id]);
                            array_push($roles, $role->name);
                        }
                        $user->roles_name = $roles;
                    }
                }
                $user->save();
                DB::commit();
                return to_route('supervisors.index')->with('message','تمت الإضافة بنجاح');
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return to_route('supervisors.index')->with('error','حدث شيء ما خاطئ');
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }


    /**
     * Display the specified resource.
     */
    public function show()
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        $pageInfo['title']= 'تعديل المشرف';
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['super-edit'])){
            $admin = Admin::find($id);
            $roles = Role::where('guard_name', 'admin')->get();
            return view('admin.supervisors.edit', compact('pageInfo', 'roles', 'admin'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    public function update(AdminRequest $request, $id)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['super-edit'])){
            try {
                DB::beginTransaction ();
                $user=Admin::find($id);
                $user->update([
                    'name'=> $request->edit_name,
                    'email'=>$request->email,
                    'phone'=>$request->phone,
                ]);
                if( $request->has('status') ){
                    $user->status="active";
                }else{
                    $user->status='inactive';
                }

                if( $request->password !=null ){
                    $user->password=Hash::make($request->password);
                }
                $user->syncRoles([]);

                    if(isset($request->roles_name)) {
                        if (is_array($request->roles_name)) {
                            $roles = array();
                            foreach ($request->roles_name as $value) {
                                $role = Role::where('id',$value)->where('guard_name','admin')->first();
                                array_push($roles, $role->name);
                                $user->assignRole($role->id);
                            }
                            $user->roles_name = $roles;
                            $user->save();
                        }
                    }

                if ($request->hasFile('avatar')){
                    $user->clearMediaCollection('avatar');
                    $user->addMediaFromRequest('avatar')->toMediaCollection('avatar');
                } else {
                    if ($user->hasMedia('avatar')){
                        $user->clearMediaCollection('avatar');
                    }
                }
                $user->save();
                DB::commit();
                return to_route('supervisors.index')->with('message','تم التعديل بنجاح');
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return to_route('supervisors.index')->with('error','حدث شيء ما خاطئ');
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy( $id)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['super-delete'])){
            try {
                $admin=Admin::find($id);
                if (Auth::guard('admin')->user()->id!=$admin->id){
                    $admin->delete();
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
                return response()->json([
                    'error'=>false,
                ]);
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }


    }
}
