<?php

namespace App\Http\Controllers;

use App\Models\Card;
use App\Models\Course;
use App\Models\Subject;
use App\Models\Teacher;
use App\Models\Subscription;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use App\Http\Requests\TeacherRequest;

class TeacherController extends Controller
{
    public function index()
    {
        $pageInfo['title'] = 'المعلمون';
       if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['teachers-list'])) || auth('partner')->check()){
         $teachers = Teacher::all();
        foreach ($teachers as $teacher) {
            $teacher->total_teacher_amount = Subscription::where('teacher_id',$teacher->id)->where('paid',1)->sum('teacher_amount');
        }
        return view('admin.teachers.index', compact('teachers', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function teacherCards($teacher, $category)
    {

        try {
            $teacher = Teacher::where('id', $teacher)->first();

            if($teacher){
              //  $cards = $teacher->cards->load('courses');
                $cards = Card::where('teacher_id',$teacher->id)->where('category_id',$category)->with(['courses','category'])->get();
                //dd($cards);
                return response()->json(['success' =>  $cards]);
            } else {
                return response()->json(['error' =>  'المعلم غير موجود']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
          // dd($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }
    public function getInfo($teacher)
    {
        try {
            $teacher = Teacher::where('id', $teacher)->first();
            if($teacher){
                return response()->json(['success' =>  $teacher]);
            } else {
                return response()->json(['error' =>  'المعلم غير موجود']);
            }
        }catch(\Exception $e){
            Log::info($e->getMessage());
            DB::rollBack();
            return response()->json(['error' =>  'حدث شيء ما خاطئ']);
        }
    }
        /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $pageInfo['title']= 'إضافة معلم';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['teachers-add'])){
            $subjects = Subject::all();
            return view('admin.teachers.create', compact('pageInfo','subjects'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    public function store(TeacherRequest $request)
    {
        $pageInfo['title']= 'إضافة معلم';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['teachers-add'])){
            try {
                DB::beginTransaction ();
                $user = Teacher::create([
                    'name' => $request->name,
                    'email' => $request->email,
                    'phone'=>$request->phone,
                    'specialization'=>$request->specialization,
                    'email_verified_at' => now(),
                    'password' => Hash::make($request->teacher_password),
                    'email_verified_at' => now(),
                ]);
                if( $request->has('status') ){
                    $user->status="active";
                }else{
                    $user->status='inactive';
                }
                if ($request->hasFile('avatar')){
                    $user->addMediaFromRequest('avatar')->toMediaCollection('avatar');
                }
                $user->save();
                Course::create([
                    'title' => 'دورة مراجعة مركزة',
                    'price' => 150000,
                    'teacher_id' => $user->id,
                ]);
                Course::create([
                    'title' => 'دورة الجزء الأول',
                    'price' => 150000,
                    'teacher_id' => $user->id,
                ]);
                Course::create([
                    'title' => 'دورة الجزء الثاني',
                    'price' => 150000,
                    'teacher_id' => $user->id,
                ]);
                Course::create([
                    'title' => 'دورة المادة كاملة',
                    'price' => 150000,
                    'teacher_id' => $user->id,
                ]);
                Course::create([
                    'title' => 'دورة المعاهد والمدارس',
                    'price' => 150000,
                    'teacher_id' => $user->id,
                ]);
                DB::commit();
                return to_route('teachers.index')->with('message','تم اضافة المعلم بنجاح');
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                //dd($e->getMessage());
                return to_route('teachers.index')->with('error','حدث شيء م خاطئ');
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }

    }

        /**
     * Show the form for editing the specified resource.
     */
    public function show($id)
    {
        $pageInfo['title']= 'بروفايل المعلم';
        if ((auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['teachers-show'])) || auth('partner')->check() ){
            $teacher = Teacher::find($id);
            $subjects = Subject::all();
            $cards = Card::where('teacher_id',$id)->withSum('subscriptions', 'number_of_cards')->get();
            $subscriptions = Subscription::where('teacher_id',$id)->where('paid',1)->get();
            $subscriptions_count = $subscriptions->sum('number_of_cards');
            $payments = $teacher->payments;
            $total_teacher_amount = Subscription::where('teacher_id',$id)->where('paid',1)->sum('teacher_amount');
            $courses = Course::where('teacher_id',$id )->get();
            return view('admin.teachers.show', compact('pageInfo','subscriptions_count', 'teacher','payments','subjects','cards','subscriptions','total_teacher_amount','courses'));
        }elseif(auth('teacher')->check()){
            if($id == Auth::guard('teacher')->user()->id ){
                $teacher = Teacher::find(Auth::guard('teacher')->user()->id);
                $subjects = Subject::all();
                $cards = Card::where('teacher_id',$id)->withSum('subscriptions', 'number_of_cards')->get();
                $payments = $teacher->payments;
                $subscriptions = Subscription::where('teacher_id',$id)->where('paid',1)->get();
                $subscriptions_count = $subscriptions->sum('number_of_cards');
                $total_teacher_amount = Subscription::where('teacher_id',$id)->where('paid',1)->sum('teacher_amount');
                $courses = Course::where('teacher_id',$id )->get();
                return view('admin.teachers.show', compact('pageInfo','subscriptions_count', 'teacher','payments','subjects','cards','subscriptions','total_teacher_amount','courses'));
            }
            abort(404);
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function edit($id)
    {
        $pageInfo['title']= 'تعديل المعلم';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['teachers-edit'])){
            $teacher = Teacher::find($id);
            $subjects = Subject::all();
            return view('admin.teachers.edit', compact('pageInfo', 'teacher','subjects'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    public function update(TeacherRequest $request, $id)
    {
        $pageInfo['title']= 'تعديل المعلم';
        if (auth('admin')->check() && Auth::guard('admin')->user()->hasAllPermissions(['teachers-edit'])){
            try {
                DB::beginTransaction ();
                $user=Teacher::find($id);
                $user->update([
                    'name' => $request->name,
                    'email' => $request->email,
                    'phone'=>$request->phone,
                    'specialization'=>$request->specialization,
                ]);
                if( $request->has('status') ){
                    $user->status="active";
                }else{
                    $user->status='inactive';
                }

                if( $request->password !=null ){
                    $user->password=Hash::make($request->password);
                }
                if ($request->hasFile('avatar')){
                    $user->clearMediaCollection('avatar');
                    $user->addMediaFromRequest('avatar')->toMediaCollection('avatar');
                } else {
                    if ($user->hasMedia('avatar')){
                        $user->clearMediaCollection('avatar');
                    }
                }
                $user->save();
                DB::commit();
                return to_route('teachers.index')->with('message','تم تعديل معلومات المعلم');
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return to_route('teachers.index')->with('error','حدث شيء ما خاطئ');
            }
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy( $id)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['teachers-delete'])){
            try {
                $teacher=Teacher::find($id);
                if ($teacher->card->count() > 0){
                    return response()->json(['error' =>  'عذراً لا يمكن الحذف ، يوجد بطاقات مرتبطة بهذا الحساب']);
                }elseif  ($teacher){
                    DB::beginTransaction ();
                    $teacher->courses()->delete();
                    $teacher->delete();
                    DB::commit();
                    return response()->json([
                        'error'=>false,
                    ]);
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }

    }
}
