<?php

namespace App\Http\Controllers;

use App\Models\Teacher;
use Illuminate\Http\Request;
use App\Models\TeacherPayment;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\TeacherPaymentRequest;

class TeacherPaymentController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $pageInfo['title'] = 'دفعات المعلمين';
        $from = "";
        $to = "";

       // if ((auth('admin')->check() &&  Auth::guard('admin')->user()->hasAllPermissions(['teacher-payment-list'])) || auth('partner')->check()){
        if ((auth('admin')->check()) && auth('admin')->user()->canAny(['teacher-payment-list']) || auth('partner')->check()){
            $payments = TeacherPayment::all();
            $teachers = Teacher::all();
            $teacher_id = '';
            return view('admin.teacher-payments.index', compact('from','to','teacher_id','teachers','payments', 'pageInfo'));
        } elseif(auth('teacher')->check()){
            $teacher = Teacher::where('id', Auth::guard('teacher')->user()->id)->first();
            $payments = TeacherPayment::where('teacher_id',$teacher->id)->get();
            $teachers = Teacher::all();
            $teacher_id = $teacher->id;
            return view('admin.teacher-payments.index', compact('from','to','teacher_id','teachers','payments', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }
    public function filter(Request $request)
    {
        $pageInfo['title'] = 'دفعات المعلمين';
        if ((auth('admin')->check() &&  Auth::guard('admin')->user()->hasAllPermissions(['teacher-payment-list'])) || auth('partner')->check()){
            $teachers = Teacher::all();
            $query = TeacherPayment::query();
            $from = '';
            if (isset($request->from)) {
                $query->where('created_at', '>=' , $request->from);
                $from = $request->from;
            }
            $to = now();
            if (isset($request->to)) {
                $query->where('created_at', '<=' , $request->to);
                $to = $request->to;
            }
            $teacher_id = '';
            if (isset($request->teacher_id)) {
                $query->where('teacher_id', $request->teacher_id);
                $teacher_id = $request->teacher_id;
            }
            $payments = $query->get();
            return view('admin.teacher-payments.index', compact('from','to','teacher_id','teachers','payments', 'pageInfo'));
        } elseif(auth('teacher')->check()){
            $teacher = Teacher::where('id', Auth::guard('teacher')->user()->id)->first();
            $teachers = Teacher::all();
            $subscriptions = TeacherPayment::where('type','platform')->get();
            $query = TeacherPayment::query();
            $teacher_id = $teacher->id;
            $from = '';
            if (isset($request->from)) {
                $query->where('created_at', '>=' , $request->from);
                $from = $request->from;
            }
            $to = now();
            if (isset($request->to)) {
                $query->where('created_at', '<=' , $request->to);
                $to = $request->to;
            }

            $payments = $query->get();
            return view('admin.teacher-payments.index', compact('from','to','teacher_id','teachers','payments', 'pageInfo'));
        }else{
            return view('admin.pages.not_allowed', compact('pageInfo'));
        }
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {

    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(TeacherPaymentRequest $request)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['teacher-payment-add'])){
            try {
               // dd($request->all());
               // dd(str_replace(',', '', $request->amount));
                $teacher = Teacher::where('id', $request->teacher_id1)->first();
                if($teacher){
                    DB::beginTransaction ();
                        $payment = TeacherPayment::create([
                            'teacher_id' => $teacher->id,
                            'unpaid_teacher_amount'=> $teacher->unpaid_amount,
                            'total_teacher_amount'=> $teacher->total_amount,
                            'amount'=> str_replace(',', '', $request->amount),
                            'remaining_unpaid_amount'=> $teacher->unpaid_amount - str_replace(',', '', $request->amount),
                        ]);
                        $payment->save();
                        $teacher->update([
                            'unpaid_amount' =>$teacher->unpaid_amount - str_replace(',', '', $request->amount),
                        ]);
                    DB::commit();
                    return response()->json(['success' =>  $payment]);
                } else {
                    return response()->json(['error' =>  'المعلم غير موجود']);
                }
            }catch(\Exception $e){
                Log::info($e->getMessage());
                DB::rollBack();
                return response()->json(['error' =>  $e->getMessage()]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للإضافة']);
        }

    }
    /**
     * Display the specified resource.
     */
    public function show($id)
    {

    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Request $request , $id)
    {

    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy($id)
    {
        if (auth('admin')->check() && Auth::guard('admin')->user()->canAny(['teacher-payment-delete'])){
            try {
                $payment=TeacherPayment::find($id);
                $teacher =Teacher::find($payment->teacher_id);
                if ($payment && $teacher){
                    $teacher->update([
                        'unpaid_amount' =>$teacher->unpaid_amount + str_replace(',', '', $payment->amount),
                    ]);
                    $payment->delete();
                }else{
                    return response()->json([
                        'error'=>true,
                        'result'=>'1',
                    ]);
                }
                return response()->json([
                    'error'=>false,
                ]);
            }catch (\Exception $e){
                return response()->json([
                    'error'=>true,
                    'result'=>$e->getMessage(),
                ]);
            }
        }else{
            return response()->json(['error' =>  'لا تملك الإذن للحذف']);
        }

    }
}
