<?php

namespace App\Models;

use App\Models\PartnerPayment;
use Laravel\Sanctum\HasApiTokens;

use Spatie\Permission\Traits\HasRoles;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Notifications\Notifiable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;

use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;
use Spatie\MediaLibrary\MediaCollections\Models\Media as Media;

class Partner extends Authenticatable implements HasMedia
{
    use HasApiTokens, HasFactory, Notifiable, HasRoles, InteractsWithMedia;

    protected $guard_name = 'partner';
    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $table='partners';
    protected $fillable = [
        'name',
        'last_login_at',
        'email',
        'phone',
        'password',
        'status',
        'percentage',
        'unpaid_amount',
        'total_amount',
    ];


    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public function subscriptions()
    {
        return $this->belongsToMany(Subscription::class)->withPivot('partner_percentage', 'amount');
    }

    public function payments()
    {
        return $this->hasMany(PartnerPayment::class);
    }
}
