<?php

namespace App\Models;

use App\Models\Card;
use App\Models\Course;

use App\Models\Subject;
use App\Models\TeacherPayment;

use Laravel\Sanctum\HasApiTokens;
use Spatie\Permission\Traits\HasRoles;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Notifications\Notifiable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;

use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;
use Spatie\MediaLibrary\MediaCollections\Models\Media as Media;

class Teacher  extends Authenticatable implements HasMedia
{
    use HasApiTokens, HasFactory, Notifiable, HasRoles, InteractsWithMedia;
    protected $guard_name = 'teacher';
    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $table='teachers';
    protected $fillable = [
        'name',
        'last_login_at',
        'email',
        'phone',
        'password',
        'status',
        'unpaid_amount',
        'total_amount',
        'specialization'
    ];


    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public function card()
    {
        return $this->hasMany(Card::class);
    }
    public function cards()
    {
        return $this->hasMany(Card::class);
    }

    public function courses()
    {
        return $this->hasMany(Course::class);
    }

    public function subject()
    {
        return $this->belongsTo(Subject::class, 'specialization','id');
    }
    public function payments()
    {
        return $this->hasMany(TeacherPayment::class);
    }

    public function subscriptions()
    {
        return $this->belongsToMany(Subscription::class)->withPivot('teacher_percentage', 'amount');
    }

}
